local RayUI, E, L, V, P, G = unpack(select(2, ...))

-- Cache global variables
-- Lua functions
local _G = _G
local ceil, format, ipairs, checkTable = ceil, string.format, ipairs, next
local tinsert, twipe, tsort, tconcat = table.insert, table.wipe, table.sort, table.concat
-- WoW API / Variables
local ADDONS = ADDONS
local ChatFrame_RemoveAllMessageGroups = ChatFrame_RemoveAllMessageGroups
local FCF_DockFrame = FCF_DockFrame
local FCF_GetChatWindowInfo = FCF_GetChatWindowInfo
local FCF_SavePositionAndDimensions = FCF_SavePositionAndDimensions
local FCF_SetChatWindowFontSize = FCF_SetChatWindowFontSize
local FCF_SetLocked = FCF_SetLocked
local FCF_SetWindowName = FCF_SetWindowName
local FCF_StopDragging = FCF_StopDragging
local FCF_UnDockFrame = FCF_UnDockFrame
local FCF_ResetChatWindows = FCF_ResetChatWindows
local FCF_OpenNewWindow = FCF_OpenNewWindow
local GetLocale = GetLocale
local GetAddOnMetadata = GetAddOnMetadata
local IsAddOnLoaded = IsAddOnLoaded
local LOOT = LOOT
local ReloadUI = ReloadUI
local SetCVar = SetCVar
local TRADE = TRADE
local GUILD_EVENT_LOG = GUILD_EVENT_LOG
local GENERAL = GENERAL

-- Global variables that we don"t cache, list them here for the mikk"s Find Globals script
-- GLOBALS: PluginInstallFrame, InstallStepComplete, PluginInstallStepComplete, NUM_CHAT_WINDOWS, LeftChatToggleButton
-- GLOBALS: ChatFrame1, ChatFrame3, ChatFrame_RemoveChannel, ChatFrame_AddChannel, ChatFrame_AddMessageGroup
-- GLOBALS: ToggleChatColorNamesByClassGroup, Skada, SkadaDB, BigWigs3DB, RayUIDataPerChar

function RayUI:SetupCVars()
	-- Setup CVar
	SetCVar("profanityFilter", 0)
	SetCVar("overrideArchive", 0)
	SetCVar("rawMouseEnable", 1)
	SetCVar("nameplateSelectedScale", 1.2)
	SetCVar("nameplateLargerScale", 1.2)
	SetCVar("nameplateOccludedAlphaMult", 0.2)
	SetCVar("countdownForCooldowns", 1)

	-- if RayUI:IsDeveloper() and RayUI:IsDeveloperRealm() then
		-- SetCVar("scriptErrors", 1)
		-- SetCVar("taintLog", 1)
	-- else
		-- SetCVar("scriptErrors", 0)
		-- SetCVar("taintLog", 0)
	-- end

	PluginInstallStepComplete.message = self.Title..L["CVars Set"]
	PluginInstallStepComplete:Show()
end

function RayUI:SetupChat()
	FCF_ResetChatWindows() -- Monitor this
	FCF_SetLocked(_G.ChatFrame1, 1)
	FCF_DockFrame(_G.ChatFrame2)
	FCF_SetLocked(_G.ChatFrame2, 1)

	FCF_OpenNewWindow(LOOT)
	FCF_UnDockFrame(_G.ChatFrame3)
	FCF_SetLocked(_G.ChatFrame3, 1)
	_G.ChatFrame3:Show()

	for i = 1, NUM_CHAT_WINDOWS do
		local frame = _G[format('ChatFrame%s', i)]

		-- move general bottom left
		if i == 1 then
			frame:ClearAllPoints()
			frame:Point('BOTTOMLEFT', _G.LeftChatToggleButton, 'TOPLEFT', 1, 3)
		elseif i == 3 then
			frame:ClearAllPoints()
			frame:Point('BOTTOMLEFT', _G.RightChatDataPanel, 'TOPLEFT', 1, 3)
		end

		FCF_SavePositionAndDimensions(frame)
		FCF_StopDragging(frame)

		-- set default Elvui font size
		FCF_SetChatWindowFontSize(nil, frame, 13)

		-- rename windows general because moved to chat #3
		if i == 1 then
			FCF_SetWindowName(frame, GENERAL)
		elseif i == 2 then
			FCF_SetWindowName(frame, GUILD_EVENT_LOG)
		elseif i == 3 then
			FCF_SetWindowName(frame, LOOT..' / '..TRADE)
		end
	end

	-- keys taken from `ChatTypeGroup` but doesnt add: 'OPENING', 'TRADESKILLS', 'PET_INFO', 'COMBAT_MISC_INFO', 'COMMUNITIES_CHANNEL', 'PET_BATTLE_COMBAT_LOG', 'PET_BATTLE_INFO', 'TARGETICONS'
	local chatGroup = { 'SYSTEM', 'CHANNEL', 'SAY', 'EMOTE', 'YELL', 'WHISPER', 'PARTY', 'PARTY_LEADER', 'RAID', 'RAID_LEADER', 'RAID_WARNING', 'INSTANCE_CHAT', 'INSTANCE_CHAT_LEADER', 'GUILD', 'OFFICER', 'MONSTER_SAY', 'MONSTER_YELL', 'MONSTER_EMOTE', 'MONSTER_WHISPER', 'MONSTER_BOSS_EMOTE', 'MONSTER_BOSS_WHISPER', 'ERRORS', 'AFK', 'DND', 'IGNORED', 'BG_HORDE', 'BG_ALLIANCE', 'BG_NEUTRAL', 'ACHIEVEMENT', 'GUILD_ACHIEVEMENT', 'BN_WHISPER', 'BN_INLINE_TOAST_ALERT' }
	ChatFrame_RemoveAllMessageGroups(_G.ChatFrame1)
	for _, v in ipairs(chatGroup) do
		ChatFrame_AddMessageGroup(_G.ChatFrame1, v)
	end

	-- keys taken from `ChatTypeGroup` which weren't added above to ChatFrame1
	chatGroup = { 'COMBAT_XP_GAIN', 'COMBAT_HONOR_GAIN', 'COMBAT_FACTION_CHANGE', 'SKILL', 'LOOT', 'CURRENCY', 'MONEY' }
	ChatFrame_RemoveAllMessageGroups(_G.ChatFrame3)
	for _, v in ipairs(chatGroup) do
		ChatFrame_AddMessageGroup(_G.ChatFrame3, v)
	end

	ChatFrame_AddChannel(_G.ChatFrame1, GENERAL)
	ChatFrame_RemoveChannel(_G.ChatFrame1, TRADE)
	ChatFrame_AddChannel(_G.ChatFrame3, TRADE)

	-- set the chat groups names in class color to enabled for all chat groups which players names appear
	chatGroup = { 'SAY', 'EMOTE', 'YELL', 'WHISPER', 'PARTY', 'PARTY_LEADER', 'RAID', 'RAID_LEADER', 'RAID_WARNING', 'INSTANCE_CHAT', 'INSTANCE_CHAT_LEADER', 'GUILD', 'OFFICER', 'ACHIEVEMENT', 'GUILD_ACHIEVEMENT', 'COMMUNITIES_CHANNEL' }
	for i = 1, _G.MAX_WOW_CHAT_CHANNELS do
		tinsert(chatGroup, 'CHANNEL'..i)
	end
	for _, v in ipairs(chatGroup) do
		ToggleChatColorNamesByClassGroup(true, v)
	end

	if E.Chat then
		E.Chat:PositionChat(true)
		if E.db.RightChatPanelFaded then
			_G.RightChatToggleButton:Click()
		end

		if E.db.LeftChatPanelFaded then
			_G.LeftChatToggleButton:Click()
		end
	end

	--[[----------------------------------
	--	ProfileDB - Chat
	--]]----------------------------------
	E.db["chat"]["fontSize"] = 12
	E.db["chat"]["tabFontOutline"] = "OUTLINE"
	E.db["chat"]["keywordSound"] = "Whisper Alert"
	E.db["chat"]["tabFontSize"] = 12
	E.db["chat"]["editBoxPosition"] = "ABOVE_CHAT"
	E.db["chat"]["panelTabTransparency"] = true
	E.db["chat"]["fontOutline"] = "OUTLINE"
	E.db["chat"]["panelWidthRight"] = 400
	E.db["chat"]["socialQueueMessages"] = true
	E.db["chat"]["customTimeColor"]["r"] = 0
	E.db["chat"]["customTimeColor"]["g"] = 0.75
	E.db["chat"]["customTimeColor"]["b"] = 0.98
	E.db["chat"]["keywords"] = "%MYNAME%, ElvUI, MerathilisUI, RayUI"
	E.db["chat"]["panelHeightRight"] = 174
	E.db["chat"]["panelHeight"] = 174
	E.db["chat"]["timeStampFormat"] = "%H:%M "
	E.db["chat"]["tapFontSize"] = 12
	E.db["chat"]["panelWidth"] = 400
	E.db["mui"]["chat"]["panelHeight"] = 174
	E.db["mui"]["chat"]["hidePlayerBrackets"] = false
	E.db["mui"]["chat"]["chatButton"] = false
	E.db["mui"]["chat"]["isExpanded"] = false
	if GetLocale() == "zhCN" then
		E.db["chat"]["font"] = "RayUI Font"
		E.db["chat"]["tabFont"] = "RayUI Font"
	end

	self:SetMoverPosition("LeftChatMover", "BOTTOMLEFT", E.UIParent, "BOTTOMLEFT", 10, 50)
	self:SetMoverPosition("RightChatMover", "BOTTOMRIGHT", E.UIParent, "BOTTOMRIGHT", -10, 50)

	E:StaggeredUpdateAll(nil, true)

	PluginInstallStepComplete.message = self.Title..L["Chat Set"]
	PluginInstallStepComplete:Show()
end

function RayUI:SetupLayout(layout)
	if layout == "dps" then		
		E.db["actionbar"]["bar1"]["inheritGlobalFade"] = true
		E.db["actionbar"]["bar2"]["inheritGlobalFade"] = true
		E.db["actionbar"]["bar3"]["enabled"] = true
		E.db["unitframe"]["units"]["raid"]["width"] = 79
		E.db["unitframe"]["units"]["raid"]["height"] = 40
		E.db["unitframe"]["units"]["raid40"]["width"] = 79
		E.db["unitframe"]["units"]["raid40"]["height"] = 40
		E.db["unitframe"]["units"]["target"]["buffs"]["sortMethod"] = "TIME_REMAINING"
		
		E:StaggeredUpdateAll(nil, true)
		
		self:SetMoverPosition("ElvAB_1", "BOTTOM", E.UIParent, "BOTTOM", 0, 145)
		self:SetMoverPosition("ElvAB_2", "BOTTOM", E.UIParent, "BOTTOM", 0, 184)
		self:SetMoverPosition("ElvAB_3", "BOTTOM", E.UIParent, "BOTTOM", 0, 40)
		self:SetMoverPosition("ElvAB_4", "LEFT", _G.LeftChatPanel, "RIGHT", 1, 0)
		self:SetMoverPosition("ElvAB_5", "RIGHT", _G.RightChatPanel, "LEFT", -1, 0)
		self:SetMoverPosition("ElvAB_6", "BOTTOM", E.UIParent, "BOTTOM", 0, 19)
		self:SetMoverPosition("PetAB", "BOTTOM", E.UIParent, "BOTTOM", 0, 81)
		self:SetMoverPosition("ShiftAB", "BOTTOMLEFT", E.UIParent, "BOTTOMLEFT", 10, 273)
		self:SetMoverPosition("ClassBarMover", "BOTTOM", E.UIParent, "BOTTOM", 0, 346)
		self:SetMoverPosition("ElvUF_PlayerMover", "BOTTOM", E.UIParent, "BOTTOM", -244, 340)
		self:SetMoverPosition("ElvUF_TargetMover", "BOTTOM", E.UIParent, "BOTTOM", 244, 340)
		self:SetMoverPosition("ElvUF_TargetCastbarMover", "TOP", _G.ElvUF_Target, "BOTTOM", 0, -17)
		self:SetMoverPosition("ElvUF_TargetTargetMover", "LEFT", _G.ElvUF_Target, "RIGHT", 2, 0)
		self:SetMoverPosition("ElvUF_PetMover", "RIGHT", _G.ElvUF_Player, "LEFT", -2, 0)
		self:SetMoverPosition("ElvUF_PetCastbarMover", "TOP", _G.ElvUF_Pet, "BOTTOM", 0, -2)
		self:SetMoverPosition("ElvUF_PlayerCastbarMover", "BOTTOM", E.UIParent, "BOTTOM", 0, 122)
		self:SetMoverPosition("ElvUF_PartyMover", "BOTTOMLEFT", E.UIParent, "BOTTOMLEFT", 257, 307)
		self:SetMoverPosition("ElvUF_RaidMover", "BOTTOMLEFT", E.UIParent, "BOTTOMLEFT", 10, 307)
		self:SetMoverPosition("ElvUF_Raid40Mover", "BOTTOMLEFT", E.UIParent, "BOTTOMLEFT", 10, 307)
		self:SetMoverPosition("ElvUF_RaidpetMover", "TOPLEFT", E.UIParent, "BOTTOMLEFT", 4, 162)
	elseif layout == "healer" then
		E.db["actionbar"]["bar1"]["inheritGlobalFade"] = false
		E.db["actionbar"]["bar2"]["inheritGlobalFade"] = false
		E.db["actionbar"]["bar3"]["enabled"] = false
		E.db["unitframe"]["units"]["raid"]["width"] = 83
		E.db["unitframe"]["units"]["raid"]["height"] = 40
		E.db["unitframe"]["units"]["raid40"]["width"] = 83
		E.db["unitframe"]["units"]["raid40"]["height"] = 30
		E.db["unitframe"]["units"]["target"]["buffs"]["sortMethod"] = "PLAYER"
		
		E:StaggeredUpdateAll(nil, true)
		
		self:SetMoverPosition("ElvAB_1", "BOTTOM", E.UIParent, "BOTTOM", 0, 41)
		self:SetMoverPosition("ElvAB_2", "BOTTOM", E.UIParent, "BOTTOM", 0, 80)
		self:SetMoverPosition("ElvAB_3", "BOTTOMRIGHT", E.UIParent, "BOTTOM", 0, 40)
		self:SetMoverPosition("ElvAB_4", "LEFT", _G.LeftChatPanel, "RIGHT", 1, 0)
		self:SetMoverPosition("ElvAB_5", "RIGHT", _G.RightChatPanel, "LEFT", -1, 0)
		self:SetMoverPosition("ElvAB_6", "BOTTOM", E.UIParent, "BOTTOM", 0, 19)
		self:SetMoverPosition("PetAB", "BOTTOMRIGHT", E.UIParent, "BOTTOM", -240, 6)
		self:SetMoverPosition("ShiftAB", "BOTTOMLEFT", E.UIParent, "BOTTOMLEFT", 10, 273)
		self:SetMoverPosition("ClassBarMover", "BOTTOM", E.UIParent, "BOTTOM", 0, 346)
		self:SetMoverPosition("ElvUF_PlayerMover", "BOTTOM", E.UIParent, "BOTTOM", -320, 340)
		self:SetMoverPosition("ElvUF_TargetMover", "BOTTOM", E.UIParent, "BOTTOM", 320, 340)
		self:SetMoverPosition("ElvUF_TargetCastbarMover", "TOP", _G.ElvUF_Target, "BOTTOM", 0, -17)
		self:SetMoverPosition("ElvUF_TargetTargetMover", "LEFT", _G.ElvUF_Target, "RIGHT", 2, 0)
		self:SetMoverPosition("ElvUF_PetMover", "RIGHT", _G.ElvUF_Player, "LEFT", -2, 0)
		self:SetMoverPosition("ElvUF_PetCastbarMover", "TOP", _G.ElvUF_Pet, "BOTTOM", 0, -2)
		self:SetMoverPosition("ElvUF_PlayerCastbarMover", "BOTTOM", E.UIParent, "BOTTOM", 0, 120)
		self:SetMoverPosition("ElvUF_PartyMover", "BOTTOMLEFT", E.UIParent, "BOTTOMLEFT", 257, 307)
		self:SetMoverPosition("ElvUF_RaidMover", "BOTTOM", E.UIParent, "BOTTOM", 0, 145)
		self:SetMoverPosition("ElvUF_Raid40Mover", "BOTTOM", E.UIParent, "BOTTOM", 0, 145)
		self:SetMoverPosition("ElvUF_RaidpetMover", "TOPLEFT", E.UIParent, "BOTTOMLEFT", 4, 162)
	end
	self:SetMoverPosition("ElvUF_FocusMover", "TOPRIGHT", E.UIParent, "TOPRIGHT", -450, -350)
	self:SetMoverPosition("ElvUF_FocusCastbarMover", "TOP", _G.ElvUF_Focus, "BOTTOM", 0, -17)
	self:SetMoverPosition("mUI_RaidMarkerBarAnchor", "BOTTOMRIGHT", E.UIParent, "BOTTOMRIGHT", -277, 178)
	self:SetMoverPosition("GMMover", "TOPLEFT", E.UIParent, "TOPLEFT", 229, -20)
	self:SetMoverPosition("BuffsMover", "TOPRIGHT", E.UIParent, "TOPRIGHT", -221, -18)
	self:SetMoverPosition("BossButton", "TOPRIGHT", E.UIParent, "TOPRIGHT", -381, -516)
	self:SetMoverPosition("LootFrameMover", "TOPRIGHT", E.UIParent, "TOPRIGHT", -495, -457)
	self:SetMoverPosition("ObjectiveFrameMover", "TOPRIGHT", E.UIParent, "TOPRIGHT", -60, -315)
	self:SetMoverPosition("mUIMiddleDTPanelMover", "BOTTOM", E.UIParent, "BOTTOM", 0, 6)
	self:SetMoverPosition("DurabilityFrameMover", "TOPRIGHT", E.UIParent, "TOPRIGHT", -4, -283)
	self:SetMoverPosition("MinimapMover", "TOPRIGHT", E.UIParent, "TOPRIGHT", -11, -17)
	self:SetMoverPosition("MicrobarMover", "TOPLEFT", E.UIParent, "TOPLEFT", 4, -4)
	self:SetMoverPosition("MER_MicroBarMover", "TOP", E.UIParent, "TOP", 0, -19)
	self:SetMoverPosition("TimeManagerFrameMover", "TOPRIGHT", E.UIParent, "TOPRIGHT", -39, -231)
	self:SetMoverPosition("ElvUIBankMover", "BOTTOMLEFT", E.UIParent, "BOTTOMLEFT", 10, 50)
	self:SetMoverPosition("SpecializationBarMover", "BOTTOM", E.UIParent, "BOTTOM", 243, 4)
	self:SetMoverPosition("ExperienceBarMover", "TOP", _G.LeftChatMover, "BOTTOM", 0, -1)
	self:SetMoverPosition("HonorBarMover", "TOP", _G.RightChatPanel, "BOTTOM", 0, -1)
	self:SetMoverPosition("ReputationBarMover", "BOTTOM", E.UIParent, "BOTTOM", 0, 32)
	self:SetMoverPosition("AzeriteBarMover", "BOTTOM", E.UIParent, "BOTTOM", 0, 24)
	self:SetMoverPosition("QuestTimerFrameMover", "TOPRIGHT", E.UIParent, "TOPRIGHT", -232, -241)
	self:SetMoverPosition("TalkingHeadFrameMover", "TOP", E.UIParent, "TOP", 0, -80)
	self:SetMoverPosition("MER_SquareMinimapButtonBarMover", "BOTTOMRIGHT", E.UIParent, "BOTTOMRIGHT", -10, 198)
	self:SetMoverPosition("ElvUIBagMover", "BOTTOMRIGHT", E.UIParent, "BOTTOMRIGHT", -28, 50)
	self:SetMoverPosition("BNETMover", "TOP", E.UIParent, "TOP", 0, -50)
	self:SetMoverPosition("ElvNP_PlayerMover", "BOTTOM", E.UIParent, "BOTTOM", 0, 360)
	self:SetMoverPosition("SquareMinimapButtonBarMover", "TOPRIGHT", _G.Minimap, "BOTTOMRIGHT", 1, -1)
	self:SetMoverPosition("TooltipMover", "BOTTOMRIGHT", E.UIParent, "BOTTOMRIGHT", -10, 280)
	self:SetMoverPosition("MER_LocPanel_Mover", "TOP", E.UIParent, "TOP", 0, 0)
	self:SetMoverPosition("PlayerPowerBarMover", "BOTTOM", E.UIParent, "BOTTOM", 0, 250)
	self:SetMoverPosition("AlertFrameMover", "TOP", E.UIParent, "TOP", 0, -140)
	self:SetMoverPosition("DebuffsMover", "TOPRIGHT", E.UIParent, "TOPRIGHT", -221, -161)
	self:SetMoverPosition("TaxiButtonMover", "BOTTOM", E.UIParent, "BOTTOM", 0, 202)
	self:SetMoverPosition("TopCenterContainerMover", "TOP", E.UIParent, "TOP", 0, -60)
	self:SetMoverPosition("AltPowerBarMover", "TOP", E.UIParent, "TOP", 0, -45)
	self:SetMoverPosition("AutoButtonAnchor3Mover", "BOTTOMLEFT", _G.RightChatPanel, "TOPLEFT", 0, 1)
	self:SetMoverPosition("AutoButtonAnchor2Mover", "BOTTOMLEFT", _G.RightChatPanel, "TOPLEFT", 0, 42)
	self:SetMoverPosition("AutoButtonAnchorMover", "BOTTOMLEFT", _G.RightChatPanel, "TOPLEFT", 0, 83)
	self:SetMoverPosition("VehicleSeatMover", "BOTTOMRIGHT", _G.RightChatPanel, "BOTTOMLEFT", -59, 0)
	self:SetMoverPosition("BelowMinimapContainerMover", "TOPLEFT", E.UIParent, "TOPLEFT", 45, -211)

	PluginInstallStepComplete.message = self.Title..L["Layout Set"]
	PluginInstallStepComplete:Show()
end

function RayUI:SetupVariables(colorMode)
	local color = E.myclass == 'PRIEST' and E.PriestColors or (_G.CUSTOM_CLASS_COLORS and _G.CUSTOM_CLASS_COLORS[E.myclass] or _G.RAID_CLASS_COLORS[E.myclass])
	local classColor = colorMode == "classColor"
	local nameColorTag = classColor and "" or "[namecolor]"

	--[[----------------------------------
	--	GlobalDB
	--]]----------------------------------
	E.global["general"]["smallerWorldMap"] = false
	E.global["general"]["animateConfig"] = false
	E.global["general"]["autoScale"] = true
	E.global["general"]["numberPrefixStyle"] = "CHINESE"
	E.global["general"]["commandBarSetting"] =  "ENABLED_RESIZEPARENT"

	--[[----------------------------------
	--	PrivateDB
	--]]----------------------------------
	E.private["general"]["chatBubbleFontSize"] = 13
	E.private["general"]["chatBubbleFontOutline"] = "OUTLINE"
	E.private["general"]["chatBubbleName"] = true
	E.private["general"]["normTex"] = "Melli"
	E.private["general"]["glossTex"] = "Melli"
	E.private["skins"]["blizzard"]["losscontrol"] = false
	E.private["skins"]["parchmentRemover"]["enable"] = false
	E.private["theme"] = "default"
	if IsAddOnLoaded("XLoot") then
		E.private["general"]["loot"] = false
		E.private["general"]["lootRoll"] = false
	else
		E.private["general"]["loot"] = true
		E.private["general"]["lootRoll"] = true
	end

	E.private["general"]["chatBubbleFont"] = "RayUI Font"
	E.private["general"]["namefont"] = "RayUI Font"
	E.private["general"]["dmgfont"] = "PT Sans Narrow"

	--[[----------------------------------
	--	ProfileDB - General
	--]]----------------------------------
	E.db["general"]["totems"]["size"] = 36
	E.db["general"]["fontSize"] = 12
	E.db["general"]["smoothingAmount"] = 0.25
	E.db["general"]["font"] = "RayUI Font"
	E.db["general"]["altPowerBar"]["font"] = "RayUI Font"
	E.db["general"]["minimap"]["locationFont"] = "RayUI Font"
	E.db["general"]["itemLevel"]["itemLevelFont"] = "PT Sans Narrow"
	E.db["general"]["interruptAnnounce"] = "RAID"
	E.db["general"]["autoRepair"] = "PLAYER"
	E.db["general"]["minimap"]["locationText"] = "HIDE"
	E.db["general"]["minimap"]["locationFontSize"] = 10
	E.db["general"]["minimap"]["resetZoom"]["enable"] = true
	E.db["general"]["minimap"]["resetZoom"]["time"] = 5
	E.db["general"]["minimap"]["icons"]["ticket"]["scale"] = 0.75
	E.db["general"]["minimap"]["icons"]["ticket"]["position"] = "TOP"
	E.db["general"]["minimap"]["icons"]["mail"]["xOffset"] = 0
	E.db["general"]["minimap"]["icons"]["mail"]["position"] = "BOTTOMLEFT"
	E.db["general"]["minimap"]["icons"]["mail"]["yOffset"] = -5
	E.db["general"]["minimap"]["size"] = 200
	E.db["general"]["talkingHeadFrameBackdrop"] = true
	E.db["general"]["bottomPanel"] = false
	E.db["general"]["valuecolor"]["a"] = 1
	E.db["general"]["loginmessage"] = false
	E.db["general"]["threat"]["enable"] = false
	E.db["general"]["threat"]["textOutline"] = "OUTLINE"
	E.db["general"]["decimalLenght"] = 0
	E.db["general"]["topPanel"] = false
	E.db["general"]["bordercolor"]["r"] = 0
	E.db["general"]["bordercolor"]["g"] = 0
	E.db["general"]["bordercolor"]["b"] = 0
	E.db["general"]["autoRoll"] = true
	E.db["general"]["hideErrorFrame"] = false
	E.db["general"]["displayInspectInfo"] = true
	E.db["general"]["bonusObjectivePosition"] = "AUTO"
	E.db["general"]["displayCharacterInfo"] = true
	E.db["general"]["backdropcolor"] = { r = 0.17, g = 0.17, b = 0.17 }
	E.db["general"]["backdropfadecolor"] = { r = 0.16, g = 0.16, b = 0.16, a = 0.4 }
	E.db["general"]["valuecolor"] = { r = color.r, g = color.g, b = color.b }
	E.db["general"]["talkingHeadFrameScale"] = 0.9
	E.db["general"]["altPowerBar"]["statusBar"] = "Melli"
	E.db["general"]["altPowerBar"]["statusBarColorGradient"] = true
	E.db["general"]["altPowerBar"]["textFormat"] = "NAMECURMAXPERC"
	E.db["general"]["altPowerBar"]["smoothbars"] = true
	E.db["general"]["altPowerBar"]["fontSize"] = 12
	E.db["general"]["vehicleSeatIndicatorSize"] = 76

	--[[----------------------------------
	--	ProfileDB - Databars
	--]]----------------------------------
	E.db["databars"]["reputation"]["height"] = 8
	E.db["databars"]["reputation"]["textSize"] = 10
	E.db["databars"]["reputation"]["width"] = 355
	E.db["databars"]["reputation"]["font"] = "RayUI Font"
	E.db["databars"]["reputation"]["orientation"] = "HORIZONTAL"
	E.db["databars"]["honor"]["enable"] = false
	E.db["databars"]["honor"]["hideOutsidePvP"] = true
	E.db["databars"]["honor"]["height"] = 8
	E.db["databars"]["honor"]["width"] = 400
	E.db["databars"]["honor"]["orientation"] = "HORIZONTAL"
	E.db["databars"]["experience"]["font"] = "RayUI Font"
	E.db["databars"]["experience"]["height"] = 8
	E.db["databars"]["experience"]["textSize"] = 10
	E.db["databars"]["experience"]["width"] = 400
	E.db["databars"]["experience"]["orientation"] = "HORIZONTAL"
	E.db["databars"]["azerite"]["enable"] = true
	E.db["databars"]["azerite"]["height"] = 8
	E.db["databars"]["azerite"]["width"] = 355
	E.db["databars"]["azerite"]["orientation"] = "HORIZONTAL"

	--[[----------------------------------
	--	ProfileDB - Auras
	--]]----------------------------------
	E.db["auras"]["font"] = "PT Sans Narrow"
	E.db["auras"]["fontOutline"] = "OUTLINE"
	E.db["auras"]["fadeThreshold"] = 10
	E.db["auras"]["buffs"]["wrapAfter"] = 10
	E.db["auras"]["buffs"]["horizontalSpacing"] = 5
	E.db["auras"]["buffs"]["verticalSpacing"] = 15
	E.db["auras"]["buffs"]["durationFontSize"] = 14
	E.db["auras"]["buffs"]["countFontsize"] = 14
	E.db["auras"]["buffs"]["size"] = 40
	E.db["auras"]["debuffs"]["horizontalSpacing"] = 5
	E.db["auras"]["debuffs"]["durationFontSize"] = 14
	E.db["auras"]["debuffs"]["countFontsize"] = 14
	E.db["auras"]["debuffs"]["size"] = 42
	E.db["auras"]["cooldown"]["secondsColor"]["b"] = 0
	E.db["auras"]["cooldown"]["daysColor"]["g"] = 0.4
	E.db["auras"]["cooldown"]["daysColor"]["r"] = 0.4
	E.db["auras"]["cooldown"]["hoursColor"]["r"] = 0.4
	E:CopyTable(E.db["auras"]["cooldown"]["expireIndicator"], E.db["auras"]["cooldown"]["expiringColor"])
	E:CopyTable(E.db["auras"]["cooldown"]["secondsIndicator"], E.db["auras"]["cooldown"]["secondsColor"])
	E:CopyTable(E.db["auras"]["cooldown"]["minutesIndicator"], E.db["auras"]["cooldown"]["minutesColor"])
	E:CopyTable(E.db["auras"]["cooldown"]["hoursIndicator"], E.db["auras"]["cooldown"]["hoursColor"])
	E:CopyTable(E.db["auras"]["cooldown"]["daysIndicator"], E.db["auras"]["cooldown"]["daysColor"])
	E:CopyTable(E.db["auras"]["cooldown"]["mmssColor"], E.db["auras"]["cooldown"]["secondsColor"])
	E:CopyTable(E.db["auras"]["cooldown"]["hhmmColor"], E.db["auras"]["cooldown"]["minutesColor"])
	E.db["auras"]["cooldown"]["checkSeconds"] = true
	E.db["auras"]["cooldown"]["mmssThreshold"] = 90

	--[[----------------------------------
	--	ProfileDB - Tooltip
	--]]----------------------------------
	E.db["tooltip"]["font"] = "RayUI Font"
	E.db["tooltip"]["fontSize"] = 13
	E.db["tooltip"]["healthBar"]["height"] = 8
	E.db["tooltip"]["healthBar"]["statusPosition"] = "TOP"
	E.db["tooltip"]["npcID"] = false
	E.db["tooltip"]["headerFontSize"] = 13
	E.db["tooltip"]["textFontSize"] = 13
	E.db["tooltip"]["cursorAnchor"] = true
	E.db["tooltip"]["style"] = "inset"
	E.db["tooltip"]["cursorAnchorType"] = "ANCHOR_CURSOR_RIGHT"
	E.db["tooltip"]["cursorAnchorY"] = 10
	E.db["tooltip"]["smallTextFontSize"] = 13
	E.db["tooltip"]["alwaysShowRealm"] = true
	E.db["tooltip"]["healthBar"]["height"] = 4
	E.db["tooltip"]["healthBar"]["fontSize"] = 12
	E.db["tooltip"]["healthBar"]["font"] = "PT Sans Narrow"
	if colorMode == "transparent" then
		E.db["tooltip"]["colorAlpha"] = 0.4
	else
		E.db["tooltip"]["colorAlpha"] = 0.8
	end

	--[[----------------------------------
	--	ProfileDB - UnitFrame
	--]]----------------------------------
	E.db["unitframe"]["font"] = "RayUI Font"
	E.db["unitframe"]["fontSize"] = 12
	E.db["unitframe"]["cooldown"]["fonts"]["font"] = "RayUI Roadway"
	E.db["unitframe"]["units"]["targettarget"]["debuffs"]["anchorPoint"] = "TOPRIGHT"
	E.db["unitframe"]["units"]["targettarget"]["debuffs"]["perrow"] = 3
	E.db["unitframe"]["units"]["targettarget"]["debuffs"]["yOffset"] = 20
	E.db["unitframe"]["units"]["targettarget"]["power"]["height"] = 4
	E.db["unitframe"]["units"]["targettarget"]["power"]["position"] = "CENTER"
	E.db["unitframe"]["units"]["targettarget"]["customTexts"] = {
		["BigName"] = {
			["attachTextTo"] = "Frame",
			["enable"] = true,
			["text_format"] = nameColorTag .. "[name:veryshort:translit]",
			["yOffset"] = 23,
			["justifyH"] = "RIGHT",
			["fontOutline"] = "OUTLINE",
			["xOffset"] = -3,
			["size"] = 13,
			["font"] = "PT Sans Narrow",
		},
	}
	E.db["unitframe"]["units"]["targettarget"]["width"] = 75
	E.db["unitframe"]["units"]["targettarget"]["name"]["attachTextTo"] = "Frame"
	E.db["unitframe"]["units"]["targettarget"]["name"]["yOffset"] = 25
	E.db["unitframe"]["units"]["targettarget"]["name"]["text_format"] = ""
	E.db["unitframe"]["units"]["targettarget"]["name"]["position"] = "RIGHT"
	E.db["unitframe"]["units"]["targettarget"]["height"] = 30
	E.db["unitframe"]["units"]["targettarget"]["health"]["bgUseBarTexture"] = true
	E.db["unitframe"]["units"]["targettarget"]["health"]["frequentUpdates"] = true
	E.db["unitframe"]["units"]["targettarget"]["raidicon"]["position"] = "TOP"
	E.db["unitframe"]["units"]["targettarget"]["raidicon"]["yOffset"] = 15
	E.db["unitframe"]["units"]["targettarget"]["power"]["text_format"] = ""
	E.db["unitframe"]["units"]["targettargettarget"]["enable"] = false
	E.db["unitframe"]["units"]["targettargettarget"]["health"]["frequentUpdates"] = true
	E.db["unitframe"]["units"]["tank"]["enable"] = false
	E.db["unitframe"]["units"]["player"]["debuffs"]["enable"] = true
	E.db["unitframe"]["units"]["player"]["debuffs"]["anchorPoint"] = "TOPRIGHT"
	E.db["unitframe"]["units"]["player"]["debuffs"]["sizeOverride"] = 30
	E.db["unitframe"]["units"]["player"]["debuffs"]["countFontSize"] = 9
	E.db["unitframe"]["units"]["player"]["debuffs"]["yOffset"] = 20
	E.db["unitframe"]["units"]["player"]["debuffs"]["countFont"] = "PT Sans Narrow"
	E.db["unitframe"]["units"]["player"]["portrait"]["overlay"] = true
	E.db["unitframe"]["units"]["player"]["health"]["xOffset"] = 0
	E.db["unitframe"]["units"]["player"]["health"]["text_format"] = ""
	E.db["unitframe"]["units"]["player"]["health"]["frequentUpdates"] = true
	E.db["unitframe"]["units"]["player"]["health"]["bgUseBarTexture"] = true
	E.db["unitframe"]["units"]["player"]["height"] = 30
	E.db["unitframe"]["units"]["player"]["CombatIcon"]["customTexture"] = ""
	E.db["unitframe"]["units"]["player"]["CombatIcon"]["size"] = 22
	E.db["unitframe"]["units"]["player"]["aurabar"]["enable"] = false
	E.db["unitframe"]["units"]["player"]["RestIcon"]["enable"] = false
	E.db["unitframe"]["units"]["player"]["power"]["detachFromFrame"] = false
	E.db["unitframe"]["units"]["player"]["power"]["powerPrediction"] = true
	E.db["unitframe"]["units"]["player"]["power"]["xOffset"] = 0
	E.db["unitframe"]["units"]["player"]["power"]["text_format"] = ""
	E.db["unitframe"]["units"]["player"]["power"]["position"] = "CENTER"
	E.db["unitframe"]["units"]["player"]["power"]["height"] = 4
	E.db["unitframe"]["units"]["player"]["power"]["hideonnpc"] = true
	E.db["unitframe"]["units"]["player"]["power"]["attachTextTo"] = "Power"
	E.db["unitframe"]["units"]["player"]["pvpIcon"]["anchorPoint"] = "TOPRIGHT"
	E.db["unitframe"]["units"]["player"]["pvpIcon"]["enable"] = true
	E.db["unitframe"]["units"]["player"]["pvpIcon"]["scale"] = 0.5
	E.db["unitframe"]["units"]["player"]["pvpIcon"]["xOffset"] = 7
	E.db["unitframe"]["units"]["player"]["pvpIcon"]["yOffset"] = 7
	E.db["unitframe"]["units"]["player"]["customTexts"] = {
		["BigName"] = {
			["attachTextTo"] = "Frame",
			["enable"] = true,
			["text_format"] = nameColorTag .. "[name]",
			["yOffset"] = 23,
			["justifyH"] = "LEFT",
			["fontOutline"] = "OUTLINE",
			["xOffset"] = 3,
			["size"] = 13,
			["font"] = "PT Sans Narrow",
		},
		["Life"] = {
			["attachTextTo"] = "Frame",
			["enable"] = true,
			["text_format"] = nameColorTag .. "[perhp<%] || [health:current]",
			["yOffset"] = -23,
			["justifyH"] = "RIGHT",
			["fontOutline"] = "OUTLINE",
			["xOffset"] = -3,
			["size"] = 13,
			["font"] = "PT Sans Narrow",
		},
		["RayUIPower"] = {
			["attachTextTo"] = "Power",
			["enable"] = true,
			["text_format"] = "[powercolor][power:current]",
			["yOffset"] = -10,
			["justifyH"] = "LEFT",
			["fontOutline"] = "OUTLINE",
			["xOffset"] = 0,
			["size"] = 13,
			["font"] = "PT Sans Narrow",
		},
	}
	E.db["unitframe"]["units"]["player"]["disableMouseoverGlow"] = true
	E.db["unitframe"]["units"]["player"]["width"] = 200
	E.db["unitframe"]["units"]["player"]["infoPanel"]["height"] = 24
	E.db["unitframe"]["units"]["player"]["infoPanel"]["transparent"] = true
	E.db["unitframe"]["units"]["player"]["castbar"]["iconXOffset"] = -5
	E.db["unitframe"]["units"]["player"]["castbar"]["height"] = 21
	E.db["unitframe"]["units"]["player"]["castbar"]["insideInfoPanel"] = false
	E.db["unitframe"]["units"]["player"]["castbar"]["iconAttached"] = false
	E.db["unitframe"]["units"]["player"]["castbar"]["width"] = 425
	E.db["unitframe"]["units"]["player"]["castbar"]["iconAttachedTo"] = "Castbar"
	E.db["unitframe"]["units"]["player"]["castbar"]["tickColor"]["a"] = 0.70186564326286
	E.db["unitframe"]["units"]["player"]["fader"]["enable"] = true
	E.db["unitframe"]["units"]["player"]["fader"]["minAlpha"] = 0.2
	E.db["unitframe"]["units"]["player"]["fader"]["hover"] = true
	E.db["unitframe"]["units"]["player"]["fader"]["combat"] = true
	E.db["unitframe"]["units"]["player"]["fader"]["power"] = true
	E.db["unitframe"]["units"]["player"]["fader"]["minAlpha"] = 0.2
	E.db["unitframe"]["units"]["player"]["fader"]["playertarget"] = true
	E.db["unitframe"]["units"]["player"]["fader"]["focus"] = true
	E.db["unitframe"]["units"]["player"]["fader"]["casting"] = true
	E.db["unitframe"]["units"]["player"]["fader"]["vehicle"] = true
	E.db["unitframe"]["units"]["player"]["fader"]["health"] = true
	E.db["unitframe"]["units"]["player"]["classbar"]["detachFromFrame"] = true
	E.db["unitframe"]["units"]["player"]["classbar"]["height"] = 15
	E.db["unitframe"]["units"]["player"]["classbar"]["timeToHold"] = 0.8
	E.db["unitframe"]["units"]["player"]["orientation"] = "RIGHT"
	E.db["unitframe"]["units"]["player"]["buffs"]["countFontSize"] = 14
	E.db["unitframe"]["units"]["player"]["buffs"]["enable"] = true
	E.db["unitframe"]["units"]["player"]["buffs"]["yOffset"] = 5
	E.db["unitframe"]["units"]["player"]["buffs"]["anchorPoint"] = "TOPRIGHT"
	E.db["unitframe"]["units"]["player"]["buffs"]["priority"] = "Blacklist,blockNoDuration,MER_RaidCDs,Personal"
	E.db["unitframe"]["units"]["player"]["buffs"]["maxDuration"] = 60
	E.db["unitframe"]["units"]["player"]["buffs"]["sizeOverride"] = 40
	E.db["unitframe"]["units"]["player"]["buffs"]["countFont"] = "PT Sans Narrow"
	E.db["unitframe"]["units"]["player"]["pvp"]["position"] = "TOP"
	E.db["unitframe"]["units"]["player"]["raidicon"]["position"] = "TOP"
	E.db["unitframe"]["units"]["player"]["raidicon"]["yOffset"] = 15
	E.db["unitframe"]["units"]["raidpet"]["enable"] = false
	E.db["unitframe"]["units"]["raid"]["debuffs"]["enable"] = false
	E.db["unitframe"]["units"]["raid"]["debuffs"]["countFontSize"] = 12
	E.db["unitframe"]["units"]["raid"]["debuffs"]["sizeOverride"] = 21
	E.db["unitframe"]["units"]["raid"]["debuffs"]["clickThrough"] = true
	E.db["unitframe"]["units"]["raid"]["debuffs"]["priority"] = "Blacklist,Boss,RaidDebuffs,Dispellable"
	E.db["unitframe"]["units"]["raid"]["debuffs"]["anchorPoint"] = "TOPRIGHT"
	E.db["unitframe"]["units"]["raid"]["debuffs"]["yOffset"] = -15
	E.db["unitframe"]["units"]["raid"]["debuffs"]["countFont"] = "PT Sans Narrow"
	E.db["unitframe"]["units"]["raid"]["rdebuffs"]["enable"] = true
	E.db["unitframe"]["units"]["raid"]["rdebuffs"]["size"] = 20
	E.db["unitframe"]["units"]["raid"]["rdebuffs"]["font"] = "PT Sans Narrow"
	E.db["unitframe"]["units"]["raid"]["rdebuffs"]["fontOutline"] = "OUTLINE"
	E.db["unitframe"]["units"]["raid"]["growthDirection"] = "RIGHT_UP"
	E.db["unitframe"]["units"]["raid"]["numGroups"] = 6
	E.db["unitframe"]["units"]["raid"]["buffIndicator"]["size"] = 10
	E.db["unitframe"]["units"]["raid"]["buffIndicator"]["fontSize"] = 11
	E.db["unitframe"]["units"]["raid"]["buffIndicator"]["style"] = "coloredIcon"
	E.db["unitframe"]["units"]["raid"]["health"]["bgUseBarTexture"] = true
	E.db["unitframe"]["units"]["raid"]["health"]["text_format"] = ""
	E.db["unitframe"]["units"]["raid"]["health"]["frequentUpdates"] = true
	E.db["unitframe"]["units"]["raid"]["roleIcon"]["size"] = 10
	E.db["unitframe"]["units"]["raid"]["roleIcon"]["tank"] = true
	E.db["unitframe"]["units"]["raid"]["roleIcon"]["heal"] = true
	E.db["unitframe"]["units"]["raid"]["roleIcon"]["damager"] = true
	E.db["unitframe"]["units"]["raid"]["roleIcon"]["position"] = "LEFT"
	E.db["unitframe"]["units"]["raid"]["roleIcon"]["xOffset"] = -5
	E.db["unitframe"]["units"]["raid"]["readycheckIcon"]["size"] = 20
	E.db["unitframe"]["units"]["raid"]["power"]["height"] = 4
	E.db["unitframe"]["units"]["raid"]["power"]["text_format"] = ""
	E.db["unitframe"]["units"]["raid"]["customTexts"] = {
		["Status"] = {
			["attachTextTo"] = "Health",
			["enable"] = true,
			["text_format"] = "[statustimer]",
			["yOffset"] = -12,
			["justifyH"] = "CENTER",
			["fontOutline"] = "OUTLINE",
			["xOffset"] = 0,
			["size"] = 12,
			["font"] = "PT Sans Narrow",
		},
		["BigName"] = {
			["attachTextTo"] = "Health",
			["enable"] = true,
			["text_format"] = nameColorTag .. "[name:veryshort:translit] [difficultycolor][smartlevel]",
			["yOffset"] = 0,
			["justifyH"] = "CENTER",
			["fontOutline"] = "OUTLINE",
			["xOffset"] = 0,
			["size"] = 12,
			["font"] = "PT Sans Narrow",
		},
	}
	E.db["unitframe"]["units"]["raid"]["healPrediction"]["enable"] = true
	E.db["unitframe"]["units"]["raid"]["width"] = 79
	E.db["unitframe"]["units"]["raid"]["infoPanel"]["height"] = 13
	E.db["unitframe"]["units"]["raid"]["infoPanel"]["transparent"] = true
	E.db["unitframe"]["units"]["raid"]["groupBy"] = "ROLE"
	E.db["unitframe"]["units"]["raid"]["name"]["text_format"] = ""
	E.db["unitframe"]["units"]["raid"]["buffs"]["enable"] = true
	E.db["unitframe"]["units"]["raid"]["buffs"]["countFontSize"] = 12
	E.db["unitframe"]["units"]["raid"]["buffs"]["useBlacklist"] = false
	E.db["unitframe"]["units"]["raid"]["buffs"]["useWhitelist"] = true
	E.db["unitframe"]["units"]["raid"]["buffs"]["playerOnly"] = false
	E.db["unitframe"]["units"]["raid"]["buffs"]["perrow"] = 1
	E.db["unitframe"]["units"]["raid"]["buffs"]["anchorPoint"] = "CENTER"
	E.db["unitframe"]["units"]["raid"]["buffs"]["useFilter"] = "MER_RaidCDs"
	E.db["unitframe"]["units"]["raid"]["buffs"]["clickThrough"] = true
	E.db["unitframe"]["units"]["raid"]["buffs"]["noConsolidated"] = false
	E.db["unitframe"]["units"]["raid"]["buffs"]["priority"] = "MER_RaidCDs"
	E.db["unitframe"]["units"]["raid"]["buffs"]["noDuration"] = false
	E.db["unitframe"]["units"]["raid"]["buffs"]["sizeOverride"] = 20
	E.db["unitframe"]["units"]["raid"]["buffs"]["countFont"] = "PT Sans Narrow"
	E.db["unitframe"]["units"]["raid"]["buffs"]["yOffset"] = 12
	E.db["unitframe"]["units"]["raid"]["height"] = 40
	E.db["unitframe"]["units"]["raid"]["verticalSpacing"] = 2
	E.db["unitframe"]["units"]["raid"]["horizontalSpacing"] = 2
	E.db["unitframe"]["units"]["raid"]["visibility"] = "[@raid31,exists][nogroup] hide;show"
	E.db["unitframe"]["units"]["raid"]["raidicon"]["attachTo"] = "CENTER"
	E.db["unitframe"]["units"]["raid"]["raidicon"]["size"] = 15
	E.db["unitframe"]["units"]["raid"]["raidicon"]["yOffset"] = 0
	E.db["unitframe"]["units"]["focustarget"]["health"]["frequentUpdates"] = true
	E.db["unitframe"]["units"]["pet"]["debuffs"]["countFontSize"] = 12
	E.db["unitframe"]["units"]["pet"]["debuffs"]["sizeOverride"] = 30
	E.db["unitframe"]["units"]["pet"]["debuffs"]["perrow"] = 3
	E.db["unitframe"]["units"]["pet"]["debuffs"]["enable"] = true
	E.db["unitframe"]["units"]["pet"]["debuffs"]["anchorPoint"] = "TOPLEFT"
	E.db["unitframe"]["units"]["pet"]["debuffs"]["yOffset"] = 15
	E.db["unitframe"]["units"]["pet"]["debuffs"]["countFont"] = "PT Sans Narrow"
	E.db["unitframe"]["units"]["pet"]["buffs"]["countFont"] = "PT Sans Narrow"
	E.db["unitframe"]["units"]["pet"]["portrait"]["overlay"] = true
	E.db["unitframe"]["units"]["pet"]["power"]["xOffset"] = 0
	E.db["unitframe"]["units"]["pet"]["power"]["attachTextTo"] = "Health"
	E.db["unitframe"]["units"]["pet"]["power"]["height"] = 4
	E.db["unitframe"]["units"]["pet"]["power"]["position"] = "RIGHT"
	E.db["unitframe"]["units"]["pet"]["customTexts"] = {
		["BigName"] = {
			["attachTextTo"] = "Frame",
			["enable"] = true,
			["text_format"] = nameColorTag .. "[name:veryshort:translit]",
			["yOffset"] = 23,
			["justifyH"] = "LEFT",
			["fontOutline"] = "OUTLINE",
			["xOffset"] = 3,
			["size"] = 12,
			["font"] = "PT Sans Narrow",
		},
	}
	E.db["unitframe"]["units"]["pet"]["name"]["attachTextTo"] = "Health"
	E.db["unitframe"]["units"]["pet"]["name"]["text_format"] = ""
	E.db["unitframe"]["units"]["pet"]["width"] = 75
	E.db["unitframe"]["units"]["pet"]["infoPanel"]["height"] = 14
	E.db["unitframe"]["units"]["pet"]["infoPanel"]["transparent"] = true
	E.db["unitframe"]["units"]["pet"]["health"]["attachTextTo"] = "InfoPanel"
	E.db["unitframe"]["units"]["pet"]["health"]["frequentUpdates"] = true
	E.db["unitframe"]["units"]["pet"]["health"]["position"] = "LEFT"
	E.db["unitframe"]["units"]["pet"]["health"]["bgUseBarTexture"] = true
	E.db["unitframe"]["units"]["pet"]["health"]["xOffset"] = 0
	E.db["unitframe"]["units"]["pet"]["fader"]["hover"] = true
	E.db["unitframe"]["units"]["pet"]["fader"]["combat"] = true
	E.db["unitframe"]["units"]["pet"]["fader"]["power"] = true
	E.db["unitframe"]["units"]["pet"]["fader"]["range"] = false
	E.db["unitframe"]["units"]["pet"]["fader"]["minAlpha"] = 0.2
	E.db["unitframe"]["units"]["pet"]["fader"]["health"] = true
	E.db["unitframe"]["units"]["pet"]["fader"]["casting"] = true
	E.db["unitframe"]["units"]["pet"]["fader"]["vehicle"] = true
	E.db["unitframe"]["units"]["pet"]["fader"]["playertarget"] = true
	E.db["unitframe"]["units"]["pet"]["buffIndicator"]["style"] = "coloredIcon"
	E.db["unitframe"]["units"]["pet"]["height"] = 30
	E.db["unitframe"]["units"]["pet"]["castbar"]["height"] = 10
	E.db["unitframe"]["units"]["pet"]["castbar"]["latency"] = true
	E.db["unitframe"]["units"]["pet"]["castbar"]["width"] = 75
	E.db["unitframe"]["units"]["pet"]["castbar"]["timeToHold"] = 0.8
	E.db["unitframe"]["units"]["pet"]["castbar"]["overlayOnFrame"] = "Health"
	E.db["unitframe"]["units"]["pet"]["aurabar"]["enable"] = false
	E.db["unitframe"]["units"]["assist"]["enable"] = false
	E.db["unitframe"]["units"]["party"]["enable"] = false
	E.db["unitframe"]["units"]["party"]["horizontalSpacing"] = 1
	E.db["unitframe"]["units"]["party"]["debuffs"]["anchorPoint"] = "LEFT"
	E.db["unitframe"]["units"]["party"]["debuffs"]["sizeOverride"] = 30
	E.db["unitframe"]["units"]["party"]["debuffs"]["countFontSize"] = 12
	E.db["unitframe"]["units"]["party"]["debuffs"]["clickThrough"] = true
	E.db["unitframe"]["units"]["party"]["debuffs"]["xOffset"] = -2
	E.db["unitframe"]["units"]["party"]["debuffs"]["priority"] = "Blacklist,Boss,RaidDebuffs,Dispellable"
	E.db["unitframe"]["units"]["party"]["debuffs"]["perrow"] = 2
	E.db["unitframe"]["units"]["party"]["debuffs"]["countFont"] = "PT Sans Narrow"
	E.db["unitframe"]["units"]["party"]["rdebuffs"]["size"] = 20
	E.db["unitframe"]["units"]["party"]["rdebuffs"]["yOffset"] = 12
	E.db["unitframe"]["units"]["party"]["rdebuffs"]["font"] = "PT Sans Narrow"
	E.db["unitframe"]["units"]["party"]["rdebuffs"]["fontOutline"] = "OUTLINE"
	E.db["unitframe"]["units"]["party"]["buffs"]["countFontSize"] = 12
	E.db["unitframe"]["units"]["party"]["buffs"]["sizeOverride"] = 20
	E.db["unitframe"]["units"]["party"]["buffs"]["useBlacklist"] = false
	E.db["unitframe"]["units"]["party"]["buffs"]["useWhitelist"] = true
	E.db["unitframe"]["units"]["party"]["buffs"]["xOffset"] = 2
	E.db["unitframe"]["units"]["party"]["buffs"]["playerOnly"] = false
	E.db["unitframe"]["units"]["party"]["buffs"]["useFilter"] = "MER_RaidCDs"
	E.db["unitframe"]["units"]["party"]["buffs"]["yOffset"] = -15
	E.db["unitframe"]["units"]["party"]["buffs"]["anchorPoint"] = "TOPLEFT"
	E.db["unitframe"]["units"]["party"]["buffs"]["noConsolidated"] = false
	E.db["unitframe"]["units"]["party"]["buffs"]["enable"] = true
	E.db["unitframe"]["units"]["party"]["buffs"]["clickThrough"] = true
	E.db["unitframe"]["units"]["party"]["buffs"]["perrow"] = 2
	E.db["unitframe"]["units"]["party"]["buffs"]["priority"] = "MER_RaidCDs"
	E.db["unitframe"]["units"]["party"]["buffs"]["noDuration"] = false
	E.db["unitframe"]["units"]["party"]["buffs"]["countFont"] = "PT Sans Narrow"
	E.db["unitframe"]["units"]["party"]["orientation"] = "MIDDLE"
	E.db["unitframe"]["units"]["party"]["groupBy"] = "ROLE"
	E.db["unitframe"]["units"]["party"]["health"]["frequentUpdates"] = true
	E.db["unitframe"]["units"]["party"]["health"]["position"] = "CENTER"
	E.db["unitframe"]["units"]["party"]["health"]["xOffset"] = 0
	E.db["unitframe"]["units"]["party"]["health"]["bgUseBarTexture"] = true
	E.db["unitframe"]["units"]["party"]["health"]["text_format"] = ""
	E.db["unitframe"]["units"]["party"]["health"]["yOffset"] = 2
	E.db["unitframe"]["units"]["party"]["roleIcon"]["xOffset"] = 1
	E.db["unitframe"]["units"]["party"]["roleIcon"]["size"] = 11
	E.db["unitframe"]["units"]["party"]["roleIcon"]["position"] = "LEFT"
	E.db["unitframe"]["units"]["party"]["targetsGroup"]["anchorPoint"] = "BOTTOM"
	E.db["unitframe"]["units"]["party"]["targetsGroup"]["name"]["text_format"] = nameColorTag .. "[name:short]"
	E.db["unitframe"]["units"]["party"]["targetsGroup"]["xOffset"] = 0
	E.db["unitframe"]["units"]["party"]["targetsGroup"]["height"] = 16
	E.db["unitframe"]["units"]["party"]["targetsGroup"]["width"] = 79
	E.db["unitframe"]["units"]["party"]["readycheckIcon"]["size"] = 20
	E.db["unitframe"]["units"]["party"]["power"]["height"] = 4
	E.db["unitframe"]["units"]["party"]["power"]["position"] = "BOTTOMRIGHT"
	E.db["unitframe"]["units"]["party"]["power"]["text_format"] = ""
	E.db["unitframe"]["units"]["party"]["power"]["yOffset"] = 2
	E.db["unitframe"]["units"]["party"]["customTexts"] = {
		["Status"] = {
			["attachTextTo"] = "Frame",
			["enable"] = true,
			["text_format"] = "[statustimer]",
			["yOffset"] = -12,
			["justifyH"] = "CENTER",
			["fontOutline"] = "OUTLINE",
			["xOffset"] = 0,
			["size"] = 12,
			["font"] = "PT Sans Narrow",
		},
		["BigName"] = {
			["attachTextTo"] = "Frame",
			["enable"] = true,
			["text_format"] = nameColorTag .. "[name:medium:translit] [difficultycolor][smartlevel]",
			["yOffset"] = 23,
			["justifyH"] = "RIGHT",
			["fontOutline"] = "OUTLINE",
			["xOffset"] = 0,
			["size"] = 13,
			["font"] = "PT Sans Narrow",
		},
	}
	E.db["unitframe"]["units"]["party"]["healPrediction"]["enable"] = true
	E.db["unitframe"]["units"]["party"]["width"] = 160
	E.db["unitframe"]["units"]["party"]["name"]["attachTextTo"] = "Frame"
	E.db["unitframe"]["units"]["party"]["name"]["text_format"] = ""
	E.db["unitframe"]["units"]["party"]["name"]["position"] = "BOTTOMLEFT"
	E.db["unitframe"]["units"]["party"]["buffIndicator"]["size"] = 10
	E.db["unitframe"]["units"]["party"]["buffIndicator"]["fontSize"] = 11
	E.db["unitframe"]["units"]["party"]["height"] = 30
	E.db["unitframe"]["units"]["party"]["verticalSpacing"] = 25
	E.db["unitframe"]["units"]["party"]["petsGroup"]["name"]["position"] = "LEFT"
	E.db["unitframe"]["units"]["party"]["petsGroup"]["height"] = 16
	E.db["unitframe"]["units"]["party"]["petsGroup"]["width"] = 60
	E.db["unitframe"]["units"]["party"]["petsGroup"]["xOffset"] = 0
	E.db["unitframe"]["units"]["party"]["petsGroup"]["yOffset"] = -1
	E.db["unitframe"]["units"]["party"]["raidicon"]["attachTo"] = "RIGHT"
	E.db["unitframe"]["units"]["party"]["raidicon"]["size"] = 16
	E.db["unitframe"]["units"]["party"]["raidicon"]["xOffset"] = -2
	E.db["unitframe"]["units"]["party"]["raidicon"]["yOffset"] = 0
	E.db["unitframe"]["units"]["raid40"]["debuffs"]["enable"] = false
	E.db["unitframe"]["units"]["raid40"]["debuffs"]["countFontSize"] = 12
	E.db["unitframe"]["units"]["raid40"]["debuffs"]["useBlacklist"] = false
	E.db["unitframe"]["units"]["raid40"]["debuffs"]["yOffset"] = -8
	E.db["unitframe"]["units"]["raid40"]["debuffs"]["anchorPoint"] = "TOPRIGHT"
	E.db["unitframe"]["units"]["raid40"]["debuffs"]["clickThrough"] = true
	E.db["unitframe"]["units"]["raid40"]["debuffs"]["useFilter"] = "Whitlist (Strict)"
	E.db["unitframe"]["units"]["raid40"]["debuffs"]["priority"] = "Blacklist,Boss,RaidDebuffs,Dispellable"
	E.db["unitframe"]["units"]["raid40"]["debuffs"]["perrow"] = 5
	E.db["unitframe"]["units"]["raid40"]["debuffs"]["sizeOverride"] = 15
	E.db["unitframe"]["units"]["raid40"]["debuffs"]["countFont"] = "PT Sans Narrow"
	E.db["unitframe"]["units"]["raid40"]["portrait"]["camDistanceScale"] = 2
	E.db["unitframe"]["units"]["raid40"]["rdebuffs"]["enable"] = true
	E.db["unitframe"]["units"]["raid40"]["rdebuffs"]["size"] = 20
	E.db["unitframe"]["units"]["raid40"]["rdebuffs"]["font"] = "PT Sans Narrow"
	E.db["unitframe"]["units"]["raid40"]["rdebuffs"]["fontOutline"] = "OUTLINE"
	E.db["unitframe"]["units"]["raid40"]["growthDirection"] = "RIGHT_UP"
	E.db["unitframe"]["units"]["raid40"]["health"]["bgUseBarTexture"] = true
	E.db["unitframe"]["units"]["raid40"]["health"]["text_format"] = ""
	E.db["unitframe"]["units"]["raid40"]["health"]["frequentUpdates"] = true
	E.db["unitframe"]["units"]["raid40"]["groupBy"] = "ROLE"
	E.db["unitframe"]["units"]["raid40"]["classHover"] = true
	E.db["unitframe"]["units"]["raid40"]["positionOverride"] = "BOTTOMRIGHT"
	E.db["unitframe"]["units"]["raid40"]["roleIcon"]["size"] = 10
	E.db["unitframe"]["units"]["raid40"]["roleIcon"]["tank"] = true
	E.db["unitframe"]["units"]["raid40"]["roleIcon"]["heal"] = true
	E.db["unitframe"]["units"]["raid40"]["roleIcon"]["damager"] = true
	E.db["unitframe"]["units"]["raid40"]["roleIcon"]["position"] = "LEFT"
	E.db["unitframe"]["units"]["raid40"]["roleIcon"]["xOffset"] = -5
	E.db["unitframe"]["units"]["raid40"]["raidWideSorting"] = false
	E.db["unitframe"]["units"]["raid40"]["readycheckIcon"]["size"] = 20
	E.db["unitframe"]["units"]["raid40"]["power"]["attachTextTo"] = "Health"
	E.db["unitframe"]["units"]["raid40"]["power"]["height"] = 4
	E.db["unitframe"]["units"]["raid40"]["power"]["enable"] = true
	E.db["unitframe"]["units"]["raid40"]["power"]["text_format"] = ""
	E.db["unitframe"]["units"]["raid40"]["customTexts"] = {
		["Status"] = {
			["attachTextTo"] = "Health",
			["enable"] = true,
			["text_format"] = "[statustimer]",
			["yOffset"] = -12,
			["justifyH"] = "CENTER",
			["fontOutline"] = "OUTLINE",
			["xOffset"] = 0,
			["size"] = 12,
			["font"] = "PT Sans Narrow",
		},
		["BigName"] = {
			["attachTextTo"] = "Health",
			["enable"] = true,
			["text_format"] = nameColorTag .. "[name:veryshort:translit] [difficultycolor][smartlevel]",
			["yOffset"] = 0,
			["justifyH"] = "CENTER",
			["fontOutline"] = "OUTLINE",
			["xOffset"] = 0,
			["size"] = 12,
			["font"] = "PT Sans Narrow",
		},
	}
	E.db["unitframe"]["units"]["raid40"]["healPrediction"]["enable"] = true
	E.db["unitframe"]["units"]["raid40"]["width"] = 79
	E.db["unitframe"]["units"]["raid40"]["infoPanel"]["height"] = 13
	E.db["unitframe"]["units"]["raid40"]["infoPanel"]["transparent"] = true
	E.db["unitframe"]["units"]["raid40"]["buffIndicator"]["size"] = 8
	E.db["unitframe"]["units"]["raid40"]["buffIndicator"]["fontSize"] = 11
	E.db["unitframe"]["units"]["raid40"]["buffIndicator"]["style"] = "coloredIcon"
	E.db["unitframe"]["units"]["raid40"]["name"]["text_format"] = ""
	E.db["unitframe"]["units"]["raid40"]["buffs"]["enable"] = true
	E.db["unitframe"]["units"]["raid40"]["buffs"]["countFontSize"] = 12
	E.db["unitframe"]["units"]["raid40"]["buffs"]["useBlacklist"] = false
	E.db["unitframe"]["units"]["raid40"]["buffs"]["playerOnly"] = false
	E.db["unitframe"]["units"]["raid40"]["buffs"]["perrow"] = 1
	E.db["unitframe"]["units"]["raid40"]["buffs"]["anchorPoint"] = "CENTER"
	E.db["unitframe"]["units"]["raid40"]["buffs"]["useFilter"] = "MER_RaidCDs"
	E.db["unitframe"]["units"]["raid40"]["buffs"]["clickThrough"] = true
	E.db["unitframe"]["units"]["raid40"]["buffs"]["noConsolidated"] = false
	E.db["unitframe"]["units"]["raid40"]["buffs"]["priority"] = "MER_RaidCDs"
	E.db["unitframe"]["units"]["raid40"]["buffs"]["noDuration"] = false
	E.db["unitframe"]["units"]["raid40"]["buffs"]["sizeOverride"] = 20
	E.db["unitframe"]["units"]["raid40"]["buffs"]["countFont"] = "PT Sans Narrow"
	E.db["unitframe"]["units"]["raid40"]["buffs"]["yOffset"] = 12
	E.db["unitframe"]["units"]["raid40"]["height"] = 40
	E.db["unitframe"]["units"]["raid40"]["verticalSpacing"] = 2
	E.db["unitframe"]["units"]["raid40"]["horizontalSpacing"] = 2
	E.db["unitframe"]["units"]["raid40"]["visibility"] = "[@raid31,noexists] hide;show"
	E.db["unitframe"]["units"]["raid40"]["raidicon"]["attachTo"] = "CENTER"
	E.db["unitframe"]["units"]["raid40"]["raidicon"]["size"] = 15
	E.db["unitframe"]["units"]["raid40"]["raidicon"]["yOffset"] = 0
	E.db["unitframe"]["units"]["focus"]["debuffs"]["anchorPoint"] = "TOPLEFT"
	E.db["unitframe"]["units"]["focus"]["debuffs"]["sizeOverride"] = 40
	E.db["unitframe"]["units"]["focus"]["debuffs"]["attachTo"] = "BUFFS"
	E.db["unitframe"]["units"]["focus"]["debuffs"]["perrow"] = 7
	E.db["unitframe"]["units"]["focus"]["debuffs"]["priority"] = "Blacklist,Friendly:Dispellable,Personal,Boss,RaidDebuffs,Whitelist"
	E.db["unitframe"]["units"]["focus"]["debuffs"]["countFontSize"] = 12
	E.db["unitframe"]["units"]["focus"]["debuffs"]["yOffset"] = 5
	E.db["unitframe"]["units"]["focus"]["disableTargetGlow"] = true
	E.db["unitframe"]["units"]["focus"]["aurabar"]["maxBars"] = 6
	E.db["unitframe"]["units"]["focus"]["aurabar"]["attachTo"] = "BUFFS"
	E.db["unitframe"]["units"]["focus"]["portrait"]["overlay"] = true
	E.db["unitframe"]["units"]["focus"]["castbar"]["insideInfoPanel"] = false
	E.db["unitframe"]["units"]["focus"]["castbar"]["iconSize"] = 42
	E.db["unitframe"]["units"]["focus"]["castbar"]["latency"] = true
	E.db["unitframe"]["units"]["focus"]["castbar"]["timeToHold"] = 0.8
	E.db["unitframe"]["units"]["focus"]["castbar"]["width"] = 200
	E.db["unitframe"]["units"]["focus"]["customTexts"] = {
		["BigName"] = {
			["attachTextTo"] = "Frame",
			["enable"] = true,
			["text_format"] = nameColorTag .. "[name:medium:translit] [difficultycolor][smartlevel][classification:icon]",
			["yOffset"] = 23,
			["justifyH"] = "RIGHT",
			["fontOutline"] = "OUTLINE",
			["xOffset"] = -3,
			["size"] = 13,
			["font"] = "PT Sans Narrow",
		},
		["Life"] = {
			["attachTextTo"] = "Frame",
			["enable"] = true,
			["text_format"] = nameColorTag .. "[health:current] || [perhp<%]",
			["yOffset"] = -23,
			["justifyH"] = "LEFT",
			["fontOutline"] = "OUTLINE",
			["xOffset"] = 3,
			["size"] = 13,
			["font"] = "PT Sans Narrow",
		},
		["RayUIPower"] = {
			["attachTextTo"] = "Frame",
			["enable"] = true,
			["text_format"] = "[powercolor][power:current]",
			["yOffset"] = -23,
			["justifyH"] = "RIGHT",
			["fontOutline"] = "OUTLINE",
			["xOffset"] = -3,
			["size"] = 13,
			["font"] = "PT Sans Narrow",
		},
	}
	E.db["unitframe"]["units"]["focus"]["disableMouseoverGlow"] = true
	E.db["unitframe"]["units"]["focus"]["width"] = 200
	E.db["unitframe"]["units"]["focus"]["infoPanel"]["height"] = 24
	E.db["unitframe"]["units"]["focus"]["infoPanel"]["transparent"] = true
	E.db["unitframe"]["units"]["focus"]["orientation"] = "LEFT"
	E.db["unitframe"]["units"]["focus"]["health"]["attachTextTo"] = "Frame"
	E.db["unitframe"]["units"]["focus"]["health"]["frequentUpdates"] = true
	E.db["unitframe"]["units"]["focus"]["health"]["xOffset"] = 0
	E.db["unitframe"]["units"]["focus"]["power"]["height"] = 4
	E.db["unitframe"]["units"]["focus"]["power"]["powerPrediction"] = true
	E.db["unitframe"]["units"]["focus"]["height"] = 30
	E.db["unitframe"]["units"]["focus"]["buffs"]["countFontSize"] = 12
	E.db["unitframe"]["units"]["focus"]["buffs"]["sizeOverride"] = 30
	E.db["unitframe"]["units"]["focus"]["buffs"]["maxDuration"] = 0
	E.db["unitframe"]["units"]["focus"]["buffs"]["perrow"] = 8
	E.db["unitframe"]["units"]["focus"]["buffs"]["enable"] = true
	E.db["unitframe"]["units"]["focus"]["buffs"]["priority"] = "Blacklist,Enemy:Dispellable,Personal,RaidBuffsElvUI"
	E.db["unitframe"]["units"]["focus"]["buffs"]["anchorPoint"] = "TOPLEFT"
	E.db["unitframe"]["units"]["focus"]["buffs"]["yOffset"] = 20
	E.db["unitframe"]["units"]["focus"]["name"]["xOffset"] = 8
	E.db["unitframe"]["units"]["focus"]["name"]["text_format"] = ""
	E.db["unitframe"]["units"]["focus"]["name"]["yOffset"] = -32
	E.db["unitframe"]["units"]["focus"]["raidicon"]["attachTo"] = "LEFT"
	E.db["unitframe"]["units"]["focus"]["raidicon"]["xOffset"] = -20
	E.db["unitframe"]["units"]["focus"]["raidicon"]["yOffset"] = 0
	E.db["unitframe"]["units"]["target"]["debuffs"]["enable"] = true
	E.db["unitframe"]["units"]["target"]["debuffs"]["anchorPoint"] = "TOPLEFT"
	E.db["unitframe"]["units"]["target"]["debuffs"]["sizeOverride"] = 40
	E.db["unitframe"]["units"]["target"]["debuffs"]["perrow"] = 7
	E.db["unitframe"]["units"]["target"]["debuffs"]["countFontSize"] = 14
	E.db["unitframe"]["units"]["target"]["debuffs"]["yOffset"] = 5
	E.db["unitframe"]["units"]["target"]["debuffs"]["countFont"] = "PT Sans Narrow"
	E.db["unitframe"]["units"]["target"]["debuffs"]["priority"] = "Blacklist,Friendly:Dispellable,Personal,RaidDebuffs,CCDebuffs,Friendly:nonPersonal"
	E.db["unitframe"]["units"]["target"]["portrait"]["overlay"] = true
	E.db["unitframe"]["units"]["target"]["portrait"]["fullOverlay"] = false
	E.db["unitframe"]["units"]["target"]["aurabar"]["enable"] = false
	E.db["unitframe"]["units"]["target"]["aurabar"]["attachTo"] = "BUFFS"
	E.db["unitframe"]["units"]["target"]["name"]["xOffset"] = 8
	E.db["unitframe"]["units"]["target"]["name"]["yOffset"] = -32
	E.db["unitframe"]["units"]["target"]["name"]["text_format"] = ""
	E.db["unitframe"]["units"]["target"]["name"]["position"] = "RIGHT"
	E.db["unitframe"]["units"]["target"]["pvpIcon"]["anchorPoint"] = "TOPLEFT"
	E.db["unitframe"]["units"]["target"]["pvpIcon"]["enable"] = true
	E.db["unitframe"]["units"]["target"]["pvpIcon"]["scale"] = 0.5
	E.db["unitframe"]["units"]["target"]["pvpIcon"]["xOffset"] = -7
	E.db["unitframe"]["units"]["target"]["pvpIcon"]["yOffset"] = 7
	E.db["unitframe"]["units"]["target"]["power"]["height"] = 4
	E.db["unitframe"]["units"]["target"]["power"]["powerPrediction"] = true
	E.db["unitframe"]["units"]["target"]["power"]["text_format"] = ""
	E.db["unitframe"]["units"]["target"]["customTexts"] = {
		["BigName"] = {
			["attachTextTo"] = "Frame",
			["enable"] = true,
			["text_format"] = nameColorTag .. "[name:medium:translit] [difficultycolor][smartlevel][classification:icon]",
			["yOffset"] = 23,
			["justifyH"] = "RIGHT",
			["fontOutline"] = "OUTLINE",
			["xOffset"] = -3,
			["size"] = 13,
			["font"] = "PT Sans Narrow",
		},
		["Life"] = {
			["attachTextTo"] = "Frame",
			["enable"] = true,
			["text_format"] = nameColorTag .. "[health:current] || [perhp<%]",
			["yOffset"] = -23,
			["justifyH"] = "LEFT",
			["fontOutline"] = "OUTLINE",
			["xOffset"] = 3,
			["size"] = 13,
			["font"] = "PT Sans Narrow",
		},
		["RayUIPower"] = {
			["attachTextTo"] = "Frame",
			["enable"] = true,
			["text_format"] = "[powercolor][power:current]",
			["yOffset"] = -23,
			["justifyH"] = "RIGHT",
			["fontOutline"] = "OUTLINE",
			["xOffset"] = -3,
			["size"] = 13,
			["font"] = "PT Sans Narrow",
		},
	}
	E.db["unitframe"]["units"]["target"]["disableMouseoverGlow"] = true
	E.db["unitframe"]["units"]["target"]["width"] = 200
	E.db["unitframe"]["units"]["target"]["infoPanel"]["height"] = 24
	E.db["unitframe"]["units"]["target"]["infoPanel"]["transparent"] = true
	E.db["unitframe"]["units"]["target"]["height"] = 30
	E.db["unitframe"]["units"]["target"]["health"]["attachTextTo"] = "Frame"
	E.db["unitframe"]["units"]["target"]["health"]["frequentUpdates"] = true
	E.db["unitframe"]["units"]["target"]["health"]["bgUseBarTexture"] = true
	E.db["unitframe"]["units"]["target"]["health"]["text_format"] = ""
	E.db["unitframe"]["units"]["target"]["health"]["xOffset"] = 0
	E.db["unitframe"]["units"]["target"]["castbar"]["latency"] = true
	E.db["unitframe"]["units"]["target"]["castbar"]["width"] = 200
	E.db["unitframe"]["units"]["target"]["castbar"]["insideInfoPanel"] = false
	E.db["unitframe"]["units"]["target"]["castbar"]["timeToHold"] = 0.8
	E.db["unitframe"]["units"]["target"]["castbar"]["overlayOnFrame"] = "Health"
	E.db["unitframe"]["units"]["target"]["orientation"] = "LEFT"
	E.db["unitframe"]["units"]["target"]["buffs"]["enable"] = true
	E.db["unitframe"]["units"]["target"]["buffs"]["anchorPoint"] = "TOPLEFT"
	E.db["unitframe"]["units"]["target"]["buffs"]["sizeOverride"] = 30
	E.db["unitframe"]["units"]["target"]["buffs"]["priority"] = "Blacklist,Enemy:Dispellable,Personal,Boss,Whitelist,PlayerBuffs,nonPersonal"
	E.db["unitframe"]["units"]["target"]["buffs"]["countFontSize"] = 12
	E.db["unitframe"]["units"]["target"]["buffs"]["yOffset"] = 20
	E.db["unitframe"]["units"]["target"]["buffs"]["countFont"] = "PT Sans Narrow"
	E.db["unitframe"]["units"]["target"]["raidicon"]["attachTo"] = "LEFT"
	E.db["unitframe"]["units"]["target"]["raidicon"]["xOffset"] = -20
	E.db["unitframe"]["units"]["target"]["raidicon"]["position"] = "TOP"
	E.db["unitframe"]["units"]["target"]["raidicon"]["yOffset"] = 0
	E.db["unitframe"]["units"]["arena"]["health"]["frequentUpdates"] = true
	E.db["unitframe"]["units"]["boss"]["debuffs"]["anchorPoint"] = "TOPLEFT"
	E.db["unitframe"]["units"]["boss"]["debuffs"]["desaturate"] = false
	E.db["unitframe"]["units"]["boss"]["debuffs"]["priority"] = "Blacklist,Boss,Personal,RaidDebuffs,Whitelist"
	E.db["unitframe"]["units"]["boss"]["debuffs"]["perrow"] = 9
	E.db["unitframe"]["units"]["boss"]["debuffs"]["yOffset"] = 5
	E.db["unitframe"]["units"]["boss"]["castbar"]["overlayOnFrame"] = "Health"
	E.db["unitframe"]["units"]["boss"]["castbar"]["iconAttachedTo"] = "Castbar"
	E.db["unitframe"]["units"]["boss"]["power"]["height"] = 3
	E.db["unitframe"]["units"]["boss"]["health"]["xOffset"] = 2
	E.db["unitframe"]["units"]["boss"]["health"]["frequentUpdates"] = true
	E.db["unitframe"]["units"]["boss"]["health"]["position"] = "LEFT"
	E.db["unitframe"]["units"]["boss"]["spacing"] = 50
	E.db["unitframe"]["units"]["boss"]["height"] = 35
	E.db["unitframe"]["units"]["boss"]["buffs"]["enable"] = false
	E.db["unitframe"]["units"]["pettarget"]["enable"] = false
	E.db["unitframe"]["units"]["pettarget"]["health"]["frequentUpdates"] = true
	E.db["unitframe"]["smoothbars"] = true
	E.db["unitframe"]["colors"]["classpower_backdrop"]["b"] = 0.11
	E.db["unitframe"]["colors"]["classpower_backdrop"]["g"] = 0.11
	E.db["unitframe"]["colors"]["classpower_backdrop"]["r"] = 0.11
	E.db["unitframe"]["colors"]["powerclass"] = not classColor
	E.db["unitframe"]["colors"]["healthclass"] = classColor
	E.db["unitframe"]["colors"]["colorhealthbyvalue"] = colorMode == "dark"
	E.db["unitframe"]["colors"]["castClassColor"] = not classColor
	E.db["unitframe"]["colors"]["health"] = { r = 0, g = 0, b = 0 }
	E.db["unitframe"]["colors"]["useDeadBackdrop"] = true
	if colorMode == "transparent" then
		E.db["unitframe"]["colors"]["transparentHealth"]= true
		E.db["unitframe"]["colors"]["transparentCastbar"]= true
		E.db["unitframe"]["colors"]["colorhealthbyvalue"] = false
		E.db["unitframe"]["colors"]["customhealthbackdrop"] = false
		E.db["unitframe"]["colors"]["customcastbarbackdrop"] = false
		E.db["unitframe"]["colors"]["invertCastbar"] = true
		E.db["unitframe"]["colors"]["classbackdrop"] = true
		E.db["unitframe"]["colors"]["health_backdrop"]= { r = 0.84, g = 0.84, b = 0.84 }
		E.db["unitframe"]["colors"]["health_backdrop_dead"] = { r = 0.48, g = 0, b = 0 }
		E.db["unitframe"]["colors"]["health"] = { r = 0.2, g = 0.2, b = 0.2 }
		E.db["unitframe"]["colors"]["frameGlow"]["targetGlow"]["enable"] = true
		E.db["unitframe"]["colors"]["frameGlow"]["targetGlow"]["class"] = true
		E.db["unitframe"]["colors"]["healthMultiplier"] = 0.75
		E.db["chat"]["panelColorConverted"] = true
		E.db["chat"]["panelColor"]["a"] = 0
	else
		E.db["unitframe"]["colors"]["transparentHealth"]= false
		E.db["unitframe"]["colors"]["transparentCastbar"]= false
		E.db["unitframe"]["colors"]["classbackdrop"]= false
		E.db["unitframe"]["colors"]["customcastbarbackdrop"] = true
		E.db["unitframe"]["colors"]["invertCastBar"] = false
		E.db["unitframe"]["colors"]["health_backdrop"]= { r = 0, g = 0, b = 0 }
		E.db["unitframe"]["colors"]["health_backdrop_dead"]["r"] = { r = 0.5, g = 0.5, b = 0.5 }
		E.db["unitframe"]["colors"]["health"] = { r = 0, g = 0, b = 0 }
		E.db["unitframe"]["colors"]["frameGlow"]["targetGlow"]["enable"] = false
		E.db["unitframe"]["colors"]["healthMultiplier"] = 0.2
		E.db["chat"]["panelColorConverted"] = true
		E.db["chat"]["panelColor"]["a"] = 0.45
	end
	E.db["unitframe"]["colors"]["frameGlow"]["mouseoverGlow"]["enable"] = true
	E.db["unitframe"]["colors"]["frameGlow"]["mouseoverGlow"]["texture"] = "ElvUI Blank"
	E.db["unitframe"]["colors"]["frameGlow"]["mouseoverGlow"]["color"] = { r = 1, g = 1, b = 1, a = 0.1}
	E.db["unitframe"]["colors"]["selection"][1]["g"] = 0.6
	E.db["unitframe"]["colors"]["selection"][1]["b"] = 0.2
	E.db["unitframe"]["colors"]["selection"][2]["b"] = 0.2
	E.db["unitframe"]["colors"]["selection"][2]["g"] = 0.86
	E.db["unitframe"]["colors"]["selection"][2]["r"] = 0.86
	E.db["unitframe"]["colors"]["selection"][3]["b"] = 0.2
	E.db["unitframe"]["colors"]["selection"][3]["g"] = 0.78
	E.db["unitframe"]["colors"]["selection"][3]["r"] = 0.2
	E.db["unitframe"]["colors"]["selection"][8]["b"] = 0.2
	E.db["unitframe"]["colors"]["selection"][8]["g"] = 0.78
	E.db["unitframe"]["colors"]["selection"][8]["r"] = 0.2
	E.db["unitframe"]["colors"]["selection"][0]["b"] = 0.2
	E.db["unitframe"]["colors"]["selection"][0]["g"] = 0.2
	E.db["unitframe"]["colors"]["selection"][0]["r"] = 0.78
	E.db["unitframe"]["colors"]["classResources"]["WARLOCK"]["b"] = 0.92
	E.db["unitframe"]["colors"]["classResources"]["WARLOCK"]["g"] = 0.52
	E.db["unitframe"]["colors"]["classResources"]["WARLOCK"]["r"] = 0.52
	E.db["unitframe"]["colors"]["classResources"]["comboPoints"][1]["b"] = 0.2
	E.db["unitframe"]["colors"]["classResources"]["comboPoints"][1]["g"] = 0.2
	E.db["unitframe"]["colors"]["classResources"]["comboPoints"][1]["r"] = 0.78
	E.db["unitframe"]["colors"]["classResources"]["comboPoints"][2]["b"] = 0.2
	E.db["unitframe"]["colors"]["classResources"]["comboPoints"][2]["g"] = 0.86
	E.db["unitframe"]["colors"]["classResources"]["comboPoints"][2]["r"] = 0.86
	E.db["unitframe"]["colors"]["classResources"]["comboPoints"][3]["b"] = 0.2
	E.db["unitframe"]["colors"]["classResources"]["comboPoints"][3]["g"] = 0.78
	E.db["unitframe"]["colors"]["classResources"]["comboPoints"][3]["r"] = 0.2
	E.db["unitframe"]["colors"]["power"]["MANA"]["b"] = 1
	E.db["unitframe"]["colors"]["power"]["MANA"]["g"] = 0.50
	E.db["unitframe"]["colors"]["power"]["MANA"]["r"] = 0
	E.db["unitframe"]["colors"]["power"]["FOCUS"]["b"] = 0.25
	E.db["unitframe"]["colors"]["power"]["FOCUS"]["g"] = 0.50
	E.db["unitframe"]["colors"]["power"]["FOCUS"]["r"] = 1
	E.db["unitframe"]["colors"]["power"]["ENERGY"]["b"] = 0.2
	E.db["unitframe"]["colors"]["power"]["ENERGY"]["g"] = 0.86
	E.db["unitframe"]["colors"]["power"]["ENERGY"]["r"] = 0.86
	E.db["unitframe"]["colors"]["power"]["RAGE"]["b"] = 0.2
	E.db["unitframe"]["colors"]["power"]["RAGE"]["g"] = 0.2
	E.db["unitframe"]["colors"]["power"]["RAGE"]["r"] = 0.78
	E.db["unitframe"]["colors"]["castColor"]["r"] = 0.2
	E.db["unitframe"]["colors"]["castColor"]["g"] = 0.78
	E.db["unitframe"]["colors"]["castColor"]["b"] = 0.2
	E.db["unitframe"]["colors"]["castbar_backdrop"]["b"] = 0.04
	E.db["unitframe"]["colors"]["castbar_backdrop"]["g"] = 0.04
	E.db["unitframe"]["colors"]["castbar_backdrop"]["r"] = 0.04
	E.db["unitframe"]["colors"]["frameGlow"]["mainGlow"]["class"] = true
	E.db["unitframe"]["colors"]["castNoInterrupt"]["b"] = 0.2
	E.db["unitframe"]["colors"]["castNoInterrupt"]["g"] = 0.2
	E.db["unitframe"]["colors"]["castNoInterrupt"]["r"] = 0.78
	E.db["unitframe"]["colors"]["transparentAurabars"] = true
	E.db["unitframe"]["colors"]["reaction"]["BAD"]["b"] = 0.2
	E.db["unitframe"]["colors"]["reaction"]["BAD"]["g"] = 0.2
	E.db["unitframe"]["colors"]["reaction"]["BAD"]["r"] = 0.78
	E.db["unitframe"]["colors"]["reaction"]["NEUTRAL"]["b"] = 0.2
	E.db["unitframe"]["colors"]["reaction"]["NEUTRAL"]["g"] = 0.86
	E.db["unitframe"]["colors"]["reaction"]["NEUTRAL"]["r"] = 0.86
	E.db["unitframe"]["colors"]["reaction"]["GOOD"]["b"] = 0.12
	E.db["unitframe"]["colors"]["reaction"]["GOOD"]["g"] = 0.78
	E.db["unitframe"]["colors"]["reaction"]["GOOD"]["r"] = 0.12
	E.db["unitframe"]["colors"]["power_backdrop"]["b"] = 0.04
	E.db["unitframe"]["colors"]["power_backdrop"]["g"] = 0.04
	E.db["unitframe"]["colors"]["power_backdrop"]["r"] = 0.04
	E.db["unitframe"]["colors"]["auraBarDebuff"]["b"] = 0.2
	E.db["unitframe"]["colors"]["auraBarDebuff"]["g"] = 0.2
	E.db["unitframe"]["colors"]["auraBarDebuff"]["r"] = 0.78
	E.db["unitframe"]["colors"]["healPrediction"]["absorbs"] = {r = 0.66, g = 1, b = 1, a = 0.7}
	E.db["unitframe"]["colors"]["healPrediction"]["overabsorbs"] = {r = 0.66, g = 1, b = 1, a = 0.7}
	E.db["unitframe"]["fontOutline"] = "OUTLINE"
	E.db["unitframe"]["smartRaidFilter"] = false
	E.db["unitframe"]["debuffHighlighting"] = "NONE"
	E.db["unitframe"]["statusbar"] = "MerathilisDefault"
	E.db["unitframe"]["cooldown"]["fonts"]["enable"] = true
	E.db["unitframe"]["cooldown"]["secondsColor"]["b"] = 0
	E.db["unitframe"]["cooldown"]["daysColor"]["g"] = 0.4
	E.db["unitframe"]["cooldown"]["daysColor"]["r"] = 0.4
	E.db["unitframe"]["cooldown"]["hoursColor"]["r"] = 0.4
	E:CopyTable(E.db["unitframe"]["cooldown"]["expireIndicator"], E.db["unitframe"]["cooldown"]["expiringColor"])
	E:CopyTable(E.db["unitframe"]["cooldown"]["secondsIndicator"], E.db["unitframe"]["cooldown"]["secondsColor"])
	E:CopyTable(E.db["unitframe"]["cooldown"]["minutesIndicator"], E.db["unitframe"]["cooldown"]["minutesColor"])
	E:CopyTable(E.db["unitframe"]["cooldown"]["hoursIndicator"], E.db["unitframe"]["cooldown"]["hoursColor"])
	E:CopyTable(E.db["unitframe"]["cooldown"]["daysIndicator"], E.db["unitframe"]["cooldown"]["daysColor"])
	E:CopyTable(E.db["unitframe"]["cooldown"]["mmssColor"], E.db["unitframe"]["cooldown"]["secondsColor"])
	E:CopyTable(E.db["unitframe"]["cooldown"]["hhmmColor"], E.db["unitframe"]["cooldown"]["minutesColor"])

	--[[----------------------------------
	--	ProfileDB - Datatexts
	--]]----------------------------------
	E.db["datatexts"]["font"] = "RayUI Font"
	E.db["datatexts"]["minimapPanels"] = false
	E.db["datatexts"]["noCombatHover"] = true
	E.db["datatexts"]["goldFormat"] = "BLIZZARD2"
	E.db["datatexts"]["panelTransparency"] = true
	E.db["datatexts"]["actionbar5"] = false
	E.db["datatexts"]["panels"]["BottomMiniPanel"] = "Time"
	E.db["datatexts"]["panels"]["RightChatDataPanel"]["left"] = "Bags"
	E.db["datatexts"]["panels"]["RightChatDataPanel"]["middle"] = "BfA Missions"
	E.db["datatexts"]["panels"]["LeftChatDataPanel"]["middle"] = "Friends"
	E.db["datatexts"]["panels"]["LeftChatDataPanel"]["right"] = "Guild"
	E.db["datatexts"]["fontSize"] = 11
	E.db["datatexts"]["fontOutline"] = "OUTLINE"
	E.db["datatexts"]["currencies"]["displayedCurrency"] = "7TH_LEGION_SERVICE_MEDAL"
	E.db["datatexts"]["wordWrap"] = true
	E.db["datatexts"]["actionbar3"] = false
	E.db["datatexts"]["panelBackdrop"] = false

	--[[----------------------------------
	--	ProfileDB - Actionbar
	--]]----------------------------------
	E.db["actionbar"]["font"] = "PT Sans Narrow"
	E.db["actionbar"]["cooldown"]["fonts"]["font"] = "RayUI Roadway"
	E.db["actionbar"]["bar1"]["heightMult"] = 2
	E.db["actionbar"]["bar1"]["inheritGlobalFade"] = true
	E.db["actionbar"]["bar1"]["buttonspacing"] = 3
	E.db["actionbar"]["bar1"]["backdrop"] = true
	E.db["actionbar"]["bar1"]["backdropSpacing"] = 3
	E.db["actionbar"]["bar2"]["heightMult"] = 2
	E.db["actionbar"]["bar2"]["inheritGlobalFade"] = true
	E.db["actionbar"]["bar2"]["buttonspacing"] = 3
	E.db["actionbar"]["bar2"]["visibility"] = "[vehicleui][overridebar][petbattle][possessbar] hide; show"
	E.db["actionbar"]["bar2"]["backdropSpacing"] = 3
	E.db["actionbar"]["bar2"]["enabled"] = true
	E.db["actionbar"]["bar3"]["backdrop"] = true
	E.db["actionbar"]["bar3"]["inheritGlobalFade"] = true
	E.db["actionbar"]["bar3"]["point"] = "TOPLEFT"
	E.db["actionbar"]["bar3"]["buttons"] = 10
	E.db["actionbar"]["bar3"]["buttonspacing"] = 3
	E.db["actionbar"]["bar3"]["buttonsPerRow"] = 12
	E.db["actionbar"]["bar3"]["backdropSpacing"] = 3
	E.db["actionbar"]["bar4"]["point"] = "TOPLEFT"
	E.db["actionbar"]["bar4"]["flyoutDirection"] = "RIGHT"
	E.db["actionbar"]["bar4"]["buttonspacing"] = 4
	E.db["actionbar"]["bar4"]["buttonsPerRow"] = 2
	E.db["actionbar"]["bar4"]["backdropSpacing"] = 1
	E.db["actionbar"]["bar4"]["buttonsize"] = 25
	E.db["actionbar"]["bar4"]["backdrop"] = true
	E.db["actionbar"]["bar4"]["inheritGlobalFade"] = false
	E.db["actionbar"]["bar4"]["widthMult"] = 1
	E.db["actionbar"]["bar5"]["point"] = "TOPRIGHT"
	E.db["actionbar"]["bar5"]["buttons"] = 12
	E.db["actionbar"]["bar5"]["buttonspacing"] = 4
	E.db["actionbar"]["bar5"]["backdrop"] = true
	E.db["actionbar"]["bar5"]["buttonsize"] = 25
	E.db["actionbar"]["bar5"]["buttonsPerRow"] = 2
	E.db["actionbar"]["bar5"]["backdropSpacing"] = 1
	E.db["actionbar"]["bar5"]["flyoutDirection"] = "LEFT"
	E.db["actionbar"]["bar5"]["inheritGlobalFade"] = false
	E.db["actionbar"]["bar5"]["widthMult"] = 1
	E.db["actionbar"]["bar6"]["inheritGlobalFade"] = true
	E.db["actionbar"]["bar6"]["backdrop"] = true
	E.db["actionbar"]["bar6"]["buttons"] = 8
	E.db["actionbar"]["bar6"]["buttonspacing"] = 3
	E.db["actionbar"]["bar6"]["buttonsPerRow"] = 8
	E.db["actionbar"]["bar6"]["backdropSpacing"] = 3
	E.db["actionbar"]["bar6"]["visibility"] = "[vehicleui][overridebar][petbattle][possessbar] hide; show"
	E.db["actionbar"]["desaturateOnCooldown"] = true
	E.db["actionbar"]["globalFadeAlpha"] = 0.8
	E.db["actionbar"]["fontOutline"] = "OUTLINE"
	E.db["actionbar"]["cooldown"]["override"] = true
	E.db["actionbar"]["cooldown"]["secondsColor"]["b"] = 0
	E.db["actionbar"]["cooldown"]["fonts"]["enable"] = true
	E.db["actionbar"]["cooldown"]["fonts"]["fontSize"] = 20
	E.db["actionbar"]["cooldown"]["daysColor"]["g"] = 0.4
	E.db["actionbar"]["cooldown"]["daysColor"]["r"] = 0.4
	E.db["actionbar"]["cooldown"]["hoursColor"]["r"] = 0.4
	E:CopyTable(E.db["actionbar"]["cooldown"]["expireIndicator"], E.db["actionbar"]["cooldown"]["expiringColor"])
	E:CopyTable(E.db["actionbar"]["cooldown"]["secondsIndicator"], E.db["actionbar"]["cooldown"]["secondsColor"])
	E:CopyTable(E.db["actionbar"]["cooldown"]["minutesIndicator"], E.db["actionbar"]["cooldown"]["minutesColor"])
	E:CopyTable(E.db["actionbar"]["cooldown"]["hoursIndicator"], E.db["actionbar"]["cooldown"]["hoursColor"])
	E:CopyTable(E.db["actionbar"]["cooldown"]["daysIndicator"], E.db["actionbar"]["cooldown"]["daysColor"])
	E:CopyTable(E.db["actionbar"]["cooldown"]["mmssColor"], E.db["actionbar"]["cooldown"]["secondsColor"])
	E:CopyTable(E.db["actionbar"]["cooldown"]["hhmmColor"], E.db["actionbar"]["cooldown"]["minutesColor"])
	E.db["actionbar"]["cooldown"]["checkSeconds"] = true
	E.db["actionbar"]["cooldown"]["mmssThreshold"] = 90
	E.db["actionbar"]["showGrid"] = false
	E.db["actionbar"]["extraActionButton"]["scale"] = 0.75
	E.db["actionbar"]["macrotext"] = true
	E.db["actionbar"]["stanceBar"]["buttonspacing"] = 3
	E.db["actionbar"]["stanceBar"]["buttonsPerRow"] = 6
	E.db["actionbar"]["stanceBar"]["point"] = "BOTTOMLEFT"
	E.db["actionbar"]["barPet"]["inheritGlobalFade"] = true
	E.db["actionbar"]["barPet"]["point"] = "BOTTOMLEFT"
	E.db["actionbar"]["barPet"]["buttons"] = 9
	E.db["actionbar"]["barPet"]["buttonspacing"] = 3
	E.db["actionbar"]["barPet"]["buttonsPerRow"] = 9
	E.db["actionbar"]["barPet"]["buttonsize"] = 24
	E.db["actionbar"]["transparent"] = true

	--[[----------------------------------
	--	ProfileDB - Nameplates
	--]]----------------------------------
	E.db["nameplates"]["fontSize"] = 12
	E.db["nameplates"]["font"] = "RayUI Font"
	E.db["nameplates"]["stackFont"] = "PT Sans Narrow"
	E.db["nameplates"]["cooldown"]["fonts"]["font"] = "RayUI Roadway"
	E.db["nameplates"]["nonTargetTransparency"] = 0.6
	E.db["nameplates"]["smoothbars"] = true
	E.db["nameplates"]["threat"]["enable"] = true
	E.db["nameplates"]["threat"]["useThreatColor"] = true
	E.db["nameplates"]["threat"]["beingTankedByTank"] = true
	E.db["nameplates"]["units"]["PLAYER"]["debuffs"]["numAuras"] = 8
	E.db["nameplates"]["units"]["PLAYER"]["debuffs"]["size"] = 24
	E.db["nameplates"]["units"]["PLAYER"]["debuffs"]["font"] = "RayUI Font"
	E.db["nameplates"]["units"]["PLAYER"]["debuffs"]["countFont"] = "PT Sans Narrow"
	E.db["nameplates"]["units"]["PLAYER"]["power"]["text"]["fontSize"] = 10
	E.db["nameplates"]["units"]["PLAYER"]["power"]["text"]["font"] = "PT Sans Narrow"
	E.db["nameplates"]["units"]["PLAYER"]["health"]["text"]["fontSize"] = 10
	E.db["nameplates"]["units"]["PLAYER"]["health"]["text"]["format"] = "[perhp<%]"
	E.db["nameplates"]["units"]["PLAYER"]["health"]["text"]["font"] = "PT Sans Narrow"
	E.db["nameplates"]["units"]["PLAYER"]["castbar"]["iconPosition"] = "LEFT"
	E.db["nameplates"]["units"]["PLAYER"]["castbar"]["fontSize"] = 10
	E.db["nameplates"]["units"]["PLAYER"]["castbar"]["font"] = "RayUI Font"
	E.db["nameplates"]["units"]["PLAYER"]["name"]["format"] = "[name]"
	E.db["nameplates"]["units"]["PLAYER"]["buffs"]["size"] = 20
	E.db["nameplates"]["units"]["PLAYER"]["buffs"]["yOffset"] = 2
	E.db["nameplates"]["units"]["PLAYER"]["buffs"]["countFont"] = "PT Sans Narrow"
	E.db["nameplates"]["units"]["PLAYER"]["level"]["font"] = "PT Sans Narrow"
	E.db["nameplates"]["units"]["PLAYER"]["name"]["font"] = "RayUI Font"
	E.db["nameplates"]["units"]["PLAYER"]["buffs"]["font"] = "RayUI Font"
	E.db["nameplates"]["units"]["TARGET"]["classpower"]["enable"] = true
	E.db["nameplates"]["units"]["TARGET"]["classpower"]["width"] = 144
	E.db["nameplates"]["units"]["TARGET"]["classpower"]["yOffset"] = 23
	E.db["nameplates"]["units"]["TARGET"]["glowStyle"] = "style2"
	E.db["nameplates"]["units"]["FRIENDLY_NPC"]["power"]["text"]["fontSize"] = 10
	E.db["nameplates"]["units"]["FRIENDLY_NPC"]["power"]["text"]["font"] = "PT Sans Narrow"
	E.db["nameplates"]["units"]["FRIENDLY_NPC"]["buffs"]["size"] = 20
	E.db["nameplates"]["units"]["FRIENDLY_NPC"]["buffs"]["yOffset"] = 2
	E.db["nameplates"]["units"]["FRIENDLY_NPC"]["buffs"]["font"] = "RayUI Font"
	E.db["nameplates"]["units"]["FRIENDLY_NPC"]["buffs"]["countFont"] = "PT Sans Narrow"
	E.db["nameplates"]["units"]["FRIENDLY_NPC"]["health"]["text"]["fontSize"] = 10
	E.db["nameplates"]["units"]["FRIENDLY_NPC"]["health"]["text"]["format"] = "[perhp<%]"
	E.db["nameplates"]["units"]["FRIENDLY_NPC"]["health"]["text"]["font"] = "PT Sans Narrow"
	E.db["nameplates"]["units"]["FRIENDLY_NPC"]["castbar"]["iconPosition"] = "LEFT"
	E.db["nameplates"]["units"]["FRIENDLY_NPC"]["castbar"]["fontSize"] = 10
	E.db["nameplates"]["units"]["FRIENDLY_NPC"]["castbar"]["font"] = "RayUI Font"
	E.db["nameplates"]["units"]["FRIENDLY_NPC"]["name"]["format"] = "[name:medium:translit]"
	E.db["nameplates"]["units"]["FRIENDLY_NPC"]["name"]["font"] = "RayUI Font"
	E.db["nameplates"]["units"]["FRIENDLY_NPC"]["debuffs"]["numAuras"] = 8
	E.db["nameplates"]["units"]["FRIENDLY_NPC"]["debuffs"]["size"] = 24
	E.db["nameplates"]["units"]["FRIENDLY_NPC"]["debuffs"]["font"] = "RayUI Font"
	E.db["nameplates"]["units"]["FRIENDLY_NPC"]["debuffs"]["countFont"] = "PT Sans Narrow"
	E.db["nameplates"]["units"]["FRIENDLY_NPC"]["level"]["format"] = "[difficultycolor][level][shortclassification]"
	E.db["nameplates"]["units"]["FRIENDLY_NPC"]["level"]["font"] = "PT Sans Narrow"
	E.db["nameplates"]["units"]["ENEMY_NPC"]["debuffs"]["numAuras"] = 8
	E.db["nameplates"]["units"]["ENEMY_NPC"]["debuffs"]["spacing"] = 3
	E.db["nameplates"]["units"]["ENEMY_NPC"]["debuffs"]["size"] = 24
	E.db["nameplates"]["units"]["ENEMY_NPC"]["debuffs"]["yOffset"] = 33
	E.db["nameplates"]["units"]["ENEMY_NPC"]["debuffs"]["anchorPoint"] = "TOPLEFT"
	E.db["nameplates"]["units"]["ENEMY_NPC"]["debuffs"]["font"] = "RayUI Font"
	E.db["nameplates"]["units"]["ENEMY_NPC"]["debuffs"]["growthX"] = "RIGHT"
	E.db["nameplates"]["units"]["ENEMY_NPC"]["debuffs"]["countFont"] = "PT Sans Narrow"
	E.db["nameplates"]["units"]["ENEMY_NPC"]["power"]["enable"] = false
	E.db["nameplates"]["units"]["ENEMY_NPC"]["power"]["text"]["fontSize"] = 10
	E.db["nameplates"]["units"]["ENEMY_NPC"]["power"]["text"]["font"] = "PT Sans Narrow"
	E.db["nameplates"]["units"]["ENEMY_NPC"]["questIcon"]["xOffset"] = 8
	E.db["nameplates"]["units"]["ENEMY_NPC"]["buffs"]["filters"]["priority"] = "Blacklist,RaidBuffsElvUI,blockNoDuration,PlayerBuffs,TurtleBuffs,CastByUnit"
	E.db["nameplates"]["units"]["ENEMY_NPC"]["buffs"]["size"] = 20
	E.db["nameplates"]["units"]["ENEMY_NPC"]["buffs"]["yOffset"] = 13
	E.db["nameplates"]["units"]["ENEMY_NPC"]["buffs"]["anchorPoint"] = "TOPLEFT"
	E.db["nameplates"]["units"]["ENEMY_NPC"]["buffs"]["font"] = "RayUI Font"
	E.db["nameplates"]["units"]["ENEMY_NPC"]["buffs"]["growthX"] = "RIGHT"
	E.db["nameplates"]["units"]["ENEMY_NPC"]["buffs"]["countFont"] = "PT Sans Narrow"
	E.db["nameplates"]["units"]["ENEMY_NPC"]["health"]["text"]["enable"] = true
	E.db["nameplates"]["units"]["ENEMY_NPC"]["health"]["text"]["fontSize"] = 10
	E.db["nameplates"]["units"]["ENEMY_NPC"]["health"]["text"]["format"] = "[perhp<%]"
	E.db["nameplates"]["units"]["ENEMY_NPC"]["health"]["text"]["font"] = "PT Sans Narrow"
	E.db["nameplates"]["units"]["ENEMY_NPC"]["health"]["healPrediction"] = true
	E.db["nameplates"]["units"]["ENEMY_NPC"]["castbar"]["iconPosition"] = "LEFT"
	E.db["nameplates"]["units"]["ENEMY_NPC"]["castbar"]["iconOffsetY"] = -1
	E.db["nameplates"]["units"]["ENEMY_NPC"]["castbar"]["iconOffsetX"] = -2
	E.db["nameplates"]["units"]["ENEMY_NPC"]["castbar"]["timeToHold"] = 0.8
	E.db["nameplates"]["units"]["ENEMY_NPC"]["castbar"]["fontSize"] = 10
	E.db["nameplates"]["units"]["ENEMY_NPC"]["castbar"]["font"] = "RayUI Font"
	E.db["nameplates"]["units"]["ENEMY_NPC"]["name"]["enable"] = true
	E.db["nameplates"]["units"]["ENEMY_NPC"]["name"]["format"] = "[name:medium:translit]"
	E.db["nameplates"]["units"]["ENEMY_NPC"]["name"]["font"] = "RayUI Font"
	E.db["nameplates"]["units"]["ENEMY_NPC"]["level"]["enable"] = true
	E.db["nameplates"]["units"]["ENEMY_NPC"]["level"]["format"] = "[difficultycolor][level][shortclassification]"
	E.db["nameplates"]["units"]["ENEMY_NPC"]["level"]["font"] = "PT Sans Narrow"
	E.db["nameplates"]["units"]["ENEMY_NPC"]["eliteIcon"]["enable"] = true
	E.db["nameplates"]["units"]["ENEMY_NPC"]["eliteIcon"]["xOffset"] = -10
	E.db["nameplates"]["units"]["ENEMY_NPC"]["pvpindicator"]["enable"] = true
	E.db["nameplates"]["units"]["ENEMY_PLAYER"]["debuffs"]["numAuras"] = 8
	E.db["nameplates"]["units"]["ENEMY_PLAYER"]["debuffs"]["size"] = 24
	E.db["nameplates"]["units"]["ENEMY_PLAYER"]["debuffs"]["anchorPoint"] = "TOPLEFT"
	E.db["nameplates"]["units"]["ENEMY_PLAYER"]["debuffs"]["font"] = "RayUI Font"
	E.db["nameplates"]["units"]["ENEMY_PLAYER"]["debuffs"]["growthX"] = "RIGHT"
	E.db["nameplates"]["units"]["ENEMY_PLAYER"]["debuffs"]["countFont"] = "PT Sans Narrow"
	E.db["nameplates"]["units"]["ENEMY_PLAYER"]["power"]["enable"] = false
	E.db["nameplates"]["units"]["ENEMY_PLAYER"]["power"]["text"]["fontSize"] = 10
	E.db["nameplates"]["units"]["ENEMY_PLAYER"]["power"]["text"]["font"] = "PT Sans Narrow"
	E.db["nameplates"]["units"]["ENEMY_PLAYER"]["buffs"]["size"] = 20
	E.db["nameplates"]["units"]["ENEMY_PLAYER"]["buffs"]["yOffset"] = 2
	E.db["nameplates"]["units"]["ENEMY_PLAYER"]["buffs"]["anchorPoint"] = "TOPLEFT"
	E.db["nameplates"]["units"]["ENEMY_PLAYER"]["buffs"]["font"] = "RayUI Font"
	E.db["nameplates"]["units"]["ENEMY_PLAYER"]["buffs"]["growthX"] = "RIGHT"
	E.db["nameplates"]["units"]["ENEMY_PLAYER"]["buffs"]["countFont"] = "PT Sans Narrow"
	E.db["nameplates"]["units"]["ENEMY_PLAYER"]["buffs"]["filters"]["priority"] = "Blacklist,Dispellable,blockNoDuration,PlayerBuffs,TurtleBuffs"
	E.db["nameplates"]["units"]["ENEMY_PLAYER"]["castbar"]["iconPosition"] = "LEFT"
	E.db["nameplates"]["units"]["ENEMY_PLAYER"]["castbar"]["fontSize"] = 10
	E.db["nameplates"]["units"]["ENEMY_PLAYER"]["castbar"]["font"] = "RayUI Font"
	E.db["nameplates"]["units"]["ENEMY_PLAYER"]["name"]["enable"] = true
	E.db["nameplates"]["units"]["ENEMY_PLAYER"]["name"]["format"] = "[name:medium:translit]"
	E.db["nameplates"]["units"]["ENEMY_PLAYER"]["name"]["font"] = "RayUI Font"
	E.db["nameplates"]["units"]["ENEMY_PLAYER"]["health"]["healPrediction"] = true
	E.db["nameplates"]["units"]["ENEMY_PLAYER"]["health"]["text"]["enable"] = true
	E.db["nameplates"]["units"]["ENEMY_PLAYER"]["health"]["text"]["fontSize"] = 10
	E.db["nameplates"]["units"]["ENEMY_PLAYER"]["health"]["text"]["format"] = "[perhp<%]"
	E.db["nameplates"]["units"]["ENEMY_PLAYER"]["health"]["text"]["font"] = "PT Sans Narrow"
	E.db["nameplates"]["units"]["ENEMY_PLAYER"]["level"]["enable"] = true
	E.db["nameplates"]["units"]["ENEMY_PLAYER"]["level"]["format"] = "[difficultycolor][level]"
	E.db["nameplates"]["units"]["ENEMY_PLAYER"]["level"]["font"] = "PT Sans Narrow"
	E.db["nameplates"]["units"]["ENEMY_PLAYER"]["pvpindicator"]["enable"] = true
	E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["debuffs"]["numAuras"] = 8
	E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["debuffs"]["size"] = 24
	E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["debuffs"]["font"] = "RayUI Font"
	E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["debuffs"]["countFont"] = "PT Sans Narrow"
	E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["power"]["text"]["fontSize"] = 10
	E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["power"]["text"]["font"] = "PT Sans Narrow"
	E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["buffs"]["size"] = 20
	E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["buffs"]["yOffset"] = 2
	E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["buffs"]["font"] = "RayUI Font"
	E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["buffs"]["countFont"] = "PT Sans Narrow"
	E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["castbar"]["iconPosition"] = "LEFT"
	E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["castbar"]["fontSize"] = 10
	E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["castbar"]["font"] = "RayUI Font"
	E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["name"]["format"] = "[name:medium:translit]"
	E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["name"]["font"] = "RayUI Font"
	E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["health"]["text"]["fontSize"] = 10
	E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["health"]["text"]["format"] = "[perhp<%]"
	E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["health"]["text"]["font"] = "PT Sans Narrow"
	E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["level"]["format"] = "[difficultycolor][level]"
	E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["level"]["font"] = "PT Sans Narrow"
	E.db["nameplates"]["stackFontSize"] = 9
	E.db["nameplates"]["clampToScreen"] = true
	E.db["nameplates"]["colors"]["power"]["RAGE"]["a"] = 1
	E.db["nameplates"]["colors"]["power"]["RAGE"]["b"] = 0.2
	E.db["nameplates"]["colors"]["power"]["RAGE"]["g"] = 0.2
	E.db["nameplates"]["colors"]["power"]["RAGE"]["r"] = 0.78
	E.db["nameplates"]["colors"]["power"]["MANA"]["a"] = 1
	E.db["nameplates"]["colors"]["power"]["MANA"]["b"] = 1
	E.db["nameplates"]["colors"]["power"]["MANA"]["g"] = 0.50
	E.db["nameplates"]["colors"]["power"]["MANA"]["r"] = 0
	E.db["nameplates"]["colors"]["power"]["FOCUS"]["a"] = 1
	E.db["nameplates"]["colors"]["power"]["FOCUS"]["b"] = 0.25
	E.db["nameplates"]["colors"]["power"]["FOCUS"]["g"] = 0.50
	E.db["nameplates"]["colors"]["power"]["FOCUS"]["r"] = 1
	E.db["nameplates"]["colors"]["power"]["ENERGY"]["a"] = 1
	E.db["nameplates"]["colors"]["power"]["ENERGY"]["b"] = 0.2
	E.db["nameplates"]["colors"]["power"]["ENERGY"]["g"] = 0.86
	E.db["nameplates"]["colors"]["power"]["ENERGY"]["r"] = 0.86
	E.db["nameplates"]["colors"]["castColor"]["b"] = 0.2
	E.db["nameplates"]["colors"]["castColor"]["g"] = 0.86
	E.db["nameplates"]["colors"]["castColor"]["r"] = 0.2
	E.db["nameplates"]["colors"]["reactions"]["good"]["b"] = 0.2
	E.db["nameplates"]["colors"]["reactions"]["good"]["g"] = 0.78
	E.db["nameplates"]["colors"]["reactions"]["good"]["r"] = 0.2
	E.db["nameplates"]["colors"]["reactions"]["bad"]["b"] = 0.2
	E.db["nameplates"]["colors"]["reactions"]["bad"]["g"] = 0.2
	E.db["nameplates"]["colors"]["reactions"]["bad"]["r"] = 0.78
	E.db["nameplates"]["colors"]["reactions"]["neutral"]["b"] = 0.2
	E.db["nameplates"]["colors"]["reactions"]["neutral"]["g"] = 0.86
	E.db["nameplates"]["colors"]["reactions"]["neutral"]["r"] = 0.86
	E.db["nameplates"]["colors"]["glowColor"]["r"] = 0
	E.db["nameplates"]["colors"]["glowColor"]["g"] = 0.74
	E.db["nameplates"]["colors"]["glowColor"]["b"] = 0.98
	E.db["nameplates"]["colors"]["selection"][2]["g"] = 0.86
	E.db["nameplates"]["colors"]["selection"][2]["r"] = 0.86
	E.db["nameplates"]["colors"]["castNoInterruptColor"]["b"] = 0.2
	E.db["nameplates"]["colors"]["castNoInterruptColor"]["g"] = 0.2
	E.db["nameplates"]["colors"]["castNoInterruptColor"]["r"] = 0.78
	E.db["nameplates"]["colors"]["classResources"]["comboPoints"][1]["b"] = 0.2
	E.db["nameplates"]["colors"]["classResources"]["comboPoints"][1]["g"] = 0.2
	E.db["nameplates"]["colors"]["classResources"]["comboPoints"][1]["r"] = 0.78
	E.db["nameplates"]["colors"]["classResources"]["comboPoints"][2]["b"] = 0.2
	E.db["nameplates"]["colors"]["classResources"]["comboPoints"][2]["g"] = 0.2
	E.db["nameplates"]["colors"]["classResources"]["comboPoints"][2]["r"] = 0.78
	E.db["nameplates"]["colors"]["classResources"]["comboPoints"][3]["b"] = 0.2
	E.db["nameplates"]["colors"]["classResources"]["comboPoints"][3]["g"] = 0.86
	E.db["nameplates"]["colors"]["classResources"]["comboPoints"][3]["r"] = 0.86
	E.db["nameplates"]["colors"]["classResources"]["comboPoints"][4]["b"] = 0.2
	E.db["nameplates"]["colors"]["classResources"]["comboPoints"][4]["g"] = 0.86
	E.db["nameplates"]["colors"]["classResources"]["comboPoints"][4]["r"] = 0.86
	E.db["nameplates"]["colors"]["classResources"]["comboPoints"][5]["b"] = 0.2
	E.db["nameplates"]["colors"]["classResources"]["comboPoints"][5]["g"] = 0.78
	E.db["nameplates"]["colors"]["classResources"]["comboPoints"][5]["r"] = 0.2
	E.db["nameplates"]["colors"]["classResources"]["comboPoints"][6]["b"] = 0.2
	E.db["nameplates"]["colors"]["classResources"]["comboPoints"][6]["g"] = 0.78
	E.db["nameplates"]["colors"]["classResources"]["comboPoints"][6]["r"] = 0.2
	E.db["nameplates"]["cooldown"]["fonts"]["enable"] = true
	E.db["nameplates"]["cooldown"]["secondsColor"]["b"] = 0
	E.db["nameplates"]["cooldown"]["daysColor"]["g"] = 0.4
	E.db["nameplates"]["cooldown"]["daysColor"]["r"] = 0.4
	E.db["nameplates"]["cooldown"]["hoursColor"]["r"] = 0.4
	E:CopyTable(E.db["nameplates"]["cooldown"]["expireIndicator"], E.db["nameplates"]["cooldown"]["expiringColor"])
	E:CopyTable(E.db["nameplates"]["cooldown"]["secondsIndicator"], E.db["nameplates"]["cooldown"]["secondsColor"])
	E:CopyTable(E.db["nameplates"]["cooldown"]["minutesIndicator"], E.db["nameplates"]["cooldown"]["minutesColor"])
	E:CopyTable(E.db["nameplates"]["cooldown"]["hoursIndicator"], E.db["nameplates"]["cooldown"]["hoursColor"])
	E:CopyTable(E.db["nameplates"]["cooldown"]["daysIndicator"], E.db["nameplates"]["cooldown"]["daysColor"])
	E:CopyTable(E.db["nameplates"]["cooldown"]["mmssColor"], E.db["nameplates"]["cooldown"]["secondsColor"])
	E:CopyTable(E.db["nameplates"]["cooldown"]["hhmmColor"], E.db["nameplates"]["cooldown"]["minutesColor"])
	E.db["nameplates"]["statusbar"] = "Melli"

	--[[----------------------------------
	--	ProfileDB - Bags
	--]]----------------------------------
	E.db["bags"]["countFontSize"] = 12
	E.db["bags"]["itemLevelFontSize"] = 12
	E.db["bags"]["alignToChat"] = false
	E.db["bags"]["moneyFormat"] = "BLIZZARD"
	E.db["bags"]["scrapIcon"] = true
	E.db["bags"]["junkDesaturate"] = true
	E.db["bags"]["vendorGrays"]["enable"] = true
	E.db["bags"]["bagSize"] = 40
	E.db["bags"]["countFontOutline"] = "OUTLINE"
	E.db["bags"]["bankSize"] = 40
	E.db["bags"]["bankWidth"] = 426
	E.db["bags"]["itemLevelFontOutline"] = "OUTLINE"
	E.db["bags"]["moneyCoins"] = false
	E.db["bags"]["bagWidth"] = 530
	E.db["bags"]["cooldown"]["override"] = true
	E.db["bags"]["cooldown"]["secondsColor"]["b"] = 0
	E.db["bags"]["cooldown"]["fonts"]["enable"] = true
	E.db["bags"]["cooldown"]["fonts"]["fontSize"] = 14
	E.db["bags"]["cooldown"]["daysColor"]["g"] = 0.4
	E.db["bags"]["cooldown"]["daysColor"]["r"] = 0.4
	E.db["bags"]["cooldown"]["hoursColor"]["r"] = 0.4
	E:CopyTable(E.db["bags"]["cooldown"]["expireIndicator"], E.db["bags"]["cooldown"]["expiringColor"])
	E:CopyTable(E.db["bags"]["cooldown"]["secondsIndicator"], E.db["bags"]["cooldown"]["secondsColor"])
	E:CopyTable(E.db["bags"]["cooldown"]["minutesIndicator"], E.db["bags"]["cooldown"]["minutesColor"])
	E:CopyTable(E.db["bags"]["cooldown"]["hoursIndicator"], E.db["bags"]["cooldown"]["hoursColor"])
	E:CopyTable(E.db["bags"]["cooldown"]["daysIndicator"], E.db["bags"]["cooldown"]["daysColor"])
	E:CopyTable(E.db["bags"]["cooldown"]["mmssColor"], E.db["bags"]["cooldown"]["secondsColor"])
	E:CopyTable(E.db["bags"]["cooldown"]["hhmmColor"], E.db["bags"]["cooldown"]["minutesColor"])
	E.db["bags"]["cooldown"]["checkSeconds"] = true
	E.db["bags"]["cooldown"]["mmssThreshold"] = 90
	E.db["bags"]["itemLevelFont"] = "PT Sans Narrow"
	E.db["bags"]["cooldown"]["fonts"]["font"] = "RayUI Roadway"
	E.db["bags"]["countFont"] = "PT Sans Narrow"
	E.db["bags"]["junkIcon"] = true

	--[[----------------------------------
	--	ProfileDB - mUI
	--]]----------------------------------
	E.db["mui"]["databars"]["progressbar"] = false
	E.db["mui"]["general"]["LoginMsg"] = false
	E.db["mui"]["general"]["splashScreen"] = false
	E.db["mui"]["general"]["panels"] = true
	E.db["mui"]["general"]["stylePanels"] = false
	E.db["mui"]["general"]["hideErrorFrame"] = false
	E.db["mui"]["armory"]["gradient"]["color"]["b"] = 0.51
	E.db["mui"]["armory"]["gradient"]["color"]["g"] = 0.31
	E.db["mui"]["armory"]["gradient"]["color"]["r"] = 0
	E.db["mui"]["armory"]["gradient"]["colorStyle"] = "CUSTOM"
	E.db["mui"]["media"]["miscText"]["gossip"]["outline"] = "OUTLINE"
	E.db["mui"]["media"]["miscText"]["gossip"]["font"] = "RayUI Font"
	E.db["mui"]["media"]["miscText"]["mail"]["outline"] = "OUTLINE"
	E.db["mui"]["media"]["miscText"]["mail"]["font"] = "RayUI Font"
	E.db["mui"]["media"]["miscText"]["editbox"]["outline"] = "OUTLINE"
	E.db["mui"]["media"]["miscText"]["editbox"]["font"] = "RayUI Font"
	E.db["mui"]["media"]["zoneText"]["subzone"]["font"] = "RayUI Font"
	E.db["mui"]["media"]["zoneText"]["pvp"]["font"] = "RayUI Font"
	E.db["mui"]["media"]["zoneText"]["zone"]["font"] = "RayUI Font"
	E.db["mui"]["armory"]["durability"]["font"] = "PT Sans Narrow"
	E.db["mui"]["armory"]["stats"]["statFonts"]["font"] = "RayUI Font"
	E.db["mui"]["armory"]["stats"]["catFonts"]["font"] = "RayUI Font"
	E.db["mui"]["unitframes"]["textures"]["castbar"] = "Melli"
	E.db["mui"]["cooldownFlash"]["maxAlpha"] = 0.7
	E.db["mui"]["cooldownFlash"]["iconSize"] = 100
	E.db["mui"]["cooldownFlash"]["enablePet"] = true
	E.db["mui"]["cooldownFlash"]["animScale"] = 1.2
	E.db["mui"]["cooldownFlash"]["fadeOutTime"] = 0.5
	E.db["mui"]["chat"]["isExpanded"] = false
	E.db["mui"]["chat"]["chatButton"] = false
	E.db["mui"]["chat"]["hidePlayerBrackets"] = false
	E.db["mui"]["chat"]["panelHeight"] = 220
	E.db["mui"]["raidCD"]["text"]["fontSize"] = 12
	E.db["mui"]["raidCD"]["text"]["font"] = "RayUI Font"
	E.db["mui"]["smb"]["enable"] = false
	E.db["mui"]["smb"]["moveQueue"] = true
	E.db["mui"]["smb"]["moveTracker"] = true
	E.db["mui"]["raidmarkers"]["enable"] = false
	E.db["mui"]["maps"]["minimap"]["coords"]["enable"] = false
	E.db["mui"]["actionbars"]["autoButtons"]["questAutoButtons"]["questBBColorByItem"] = false
	E.db["mui"]["actionbars"]["autoButtons"]["questAutoButtons"]["questBBColor"]["b"] = 0
	E.db["mui"]["actionbars"]["autoButtons"]["questAutoButtons"]["questBBColor"]["g"] = 0
	E.db["mui"]["actionbars"]["autoButtons"]["questAutoButtons"]["questBBColor"]["r"] = 0
	E.db["mui"]["actionbars"]["autoButtons"]["soltAutoButtons"]["slotBBColorByItem"] = false
	E.db["mui"]["actionbars"]["autoButtons"]["soltAutoButtons"]["slotBBColor"]["b"] = 0
	E.db["mui"]["actionbars"]["autoButtons"]["soltAutoButtons"]["slotBBColor"]["g"] = 0
	E.db["mui"]["actionbars"]["autoButtons"]["soltAutoButtons"]["slotBBColor"]["r"] = 0
	E.db["mui"]["actionbars"]["autoButtons"]["usableAutoButtons"]["usableBBColorByItem"] = false
	E.db["mui"]["actionbars"]["autoButtons"]["usableAutoButtons"]["usableBBColor"]["b"] = 0
	E.db["mui"]["actionbars"]["autoButtons"]["usableAutoButtons"]["usableBBColor"]["g"] = 0
	E.db["mui"]["actionbars"]["autoButtons"]["usableAutoButtons"]["usableBBColor"]["r"] = 0
	E.db["mui"]["actionbars"]["specBar"]["enable"] = false
	E.db["mui"]["actionbars"]["equipBar"]["enable"] = false
	E.db["mui"]["installed"] = true
	E.db["mui"]["locPanel"]["enable"] = true
	E.db["mui"]["locPanel"]["colorType_Coords"] = "CLASS"
	E.db["mui"]["locPanel"]["template"] = "NoBackdrop"
	E.db["mui"]["locPanel"]["orderhallhide"] = true
	E.db["mui"]["locPanel"]["colorType"] = "DEFAULT"
	E.db["mui"]["locPanel"]["font"] = "RayUI Font"
	E.db["mui"]["locPanel"]["portals"]["justify"] = "CENTER"
	E.db["mui"]["locPanel"]["portals"]["customWidth"] = true
	E.db["mui"]["locPanel"]["coordshide"] = true
	E.db["mui"]["locPanel"]["height"] = 20
	E.db["mui"]["locPanel"]["format"] = "%.1f"
	E.db["mui"]["locPanel"]["width"] = 265
	E.db["mui"]["locPanel"]["combathide"] = false
	E.db["mui"]["datatexts"]["threatBar"]["textSize"] = 12
	E.db["mui"]["datatexts"]["rightChatTabDatatextPanel"]["enable"] = false
	E.db["mui"]["datatexts"]["panels"]["ChatTab_Datatext_Panel"]["right"] = "Gold"
	E.db["mui"]["datatexts"]["panels"]["ChatTab_Datatext_Panel"]["left"] = "Bags"
	E.db["mui"]["datatexts"]["panels"]["ChatTab_Datatext_Panel"]["middle"] = "Durability"
	E.db["mui"]["datatexts"]["panels"]["mUIMiddleDTPanel"]["right"] = "MovementSpeed"
	E.db["mui"]["datatexts"]["panels"]["mUIMiddleDTPanel"]["left"] = "Durability"
	E.db["mui"]["datatexts"]["panels"]["mUIMiddleDTPanel"]["middle"] = "System"
	E.db["mui"]["datatexts"]["middle"]["width"] = 355
	E.db["mui"]["datatexts"]["middle"]["backdrop"] = true
	E.db["mui"]["datatexts"]["middle"]["transparent"] = false
	E.db["mui"]["nameplates"]["castbarShield"] = false
	E.db["mui"]["nameHover"]["enable"] = false
	E.db["mui"]["microBar"]["enable"] = true
	E.db["mui"]["microBar"]["hideInOrderHall"] = true
	E.db["mui"]["microBar"]["hideInCombat"] = false
	E.db["mui"]["actionbars"]["autoButtons"]["whiteList"][169868] = true
	E.db["mui"]["unitframes"]["healPrediction"] = true

	--[[----------------------------------
	--	ProfileDB - Cooldown
	--]]----------------------------------
	E:CopyTable(E.db["cooldown"]["expireIndicator"], E.db["cooldown"]["expiringColor"])
	E:CopyTable(E.db["cooldown"]["secondsIndicator"], E.db["cooldown"]["secondsColor"])
	E:CopyTable(E.db["cooldown"]["minutesIndicator"], E.db["cooldown"]["minutesColor"])
	E:CopyTable(E.db["cooldown"]["hoursIndicator"], E.db["cooldown"]["hoursColor"])
	E:CopyTable(E.db["cooldown"]["daysIndicator"], E.db["cooldown"]["daysColor"])

	E:StaggeredUpdateAll(nil, true)

	PluginInstallStepComplete.message = self.Title..L["Profile Set"]
	PluginInstallStepComplete:Show()
end

local addonNames = {}
local profilesFailed = format("|cff00c0fa%s |r", L["RayUI didn't find any supported addons for profile creation"])

RayUI.isInstallerRunning = false

function RayUI:SetupAddOns()
	RayUI.isInstallerRunning = true -- don't print when applying profile that doesn't exist

	--ElvUI_FCT
	if RayUI:IsAddOnEnabled("ElvUI_FCT") then
		RayUI:LoadFCTProfile()
		tinsert(addonNames, "ElvUI_FCT")
	end

	if checkTable(addonNames) ~= nil then
		local profileString = format("|cfffff400%s |r", L["RayUI successfully created and applied profile(s) for:"].."\n")

		tsort(addonNames, function(a, b) return a < b end)
		local names = tconcat(addonNames, ", ")
		profileString = profileString..names

		PluginInstallFrame.Desc4:SetText(profileString..'.')
	else
		PluginInstallFrame.Desc4:SetText(profilesFailed)
	end

	PluginInstallStepComplete.message = self.Title..L['Addons Set']
	PluginInstallStepComplete:Show()
	twipe(addonNames)

	E:StaggeredUpdateAll(nil, true)
end

local function InstallComplete()
	E.private.install_complete = E.version
	E.db.mui.installed = true
	E.db.rayui.installed = true
	RayUIDataPerChar = RayUI.Version

	ReloadUI()
end

-- ElvUI PlugIn installer
RayUI.installTable = {
	["Name"] = "|cff7aa6d6Ray|r|cffff0000U|r|cff7aa6d6I|r",
	["Title"] = L["|cff7aa6d6Ray|r|cffff0000U|r|cff7aa6d6I|r Installation"],
	["tutorialImage"] = [[Interface\AddOns\ElvUI_RayUI\Media\Textures\Logo]],
	["tutorialImageSize"] = {128, 128},
	["tutorialImagePoint"] = {0, 30},
	["Pages"] = {
		[1] = function()
			PluginInstallFrame.SubTitle:SetFormattedText(L["Welcome to RayUI |cff00c0faVersion|r %s, for ElvUI %s."], RayUI.Version, E.version)
			PluginInstallFrame.Desc1:SetText(L["By pressing the Continue button, RayUI will be applied in your current ElvUI installation.\r\r|cffff8000 TIP: It would be nice if you apply the changes in a new profile, just in case you don't like the result.|r"])
			PluginInstallFrame.Desc2:SetText(L["Please press the continue button to go onto the next step."])
			PluginInstallFrame.Option1:Show()
			PluginInstallFrame.Option1:SetScript("OnClick", function() InstallComplete() end)
			PluginInstallFrame.Option1:SetText(L["Skip Process"])
		end,
		[2] = function()
			PluginInstallFrame.SubTitle:SetText(L["Profiles"])
			PluginInstallFrame.Desc1:SetText(L["This part of the installation process let you create a new profile or install |cff7aa6d6Ray|r|cffff0000U|r|cff7aa6d6I|r settings to your current profile."])
			PluginInstallFrame.Desc2:SetFormattedText(L["|cffff8000Your currently active ElvUI profile is:|r %s."], "|cff00c0fa".._G.ElvUI[1].data:GetCurrentProfile().."|r")
			PluginInstallFrame.Desc3:SetText(L["Importance: |cffff0000Very High|r"])
			PluginInstallFrame.Option1:Show()
			PluginInstallFrame.Option1:SetScript("OnClick", function() RayUI:NewProfile(false) end)
			PluginInstallFrame.Option1:SetText(L["Current"])
			PluginInstallFrame.Option2:Show()
			PluginInstallFrame.Option2:SetScript("OnClick", function() RayUI:NewProfile(true, "RayUI") end)
			PluginInstallFrame.Option2:SetText(_G.NEW)
		end,
		[3] = function()
			PluginInstallFrame.SubTitle:SetText(L["Variables"])
			PluginInstallFrame.Desc1:SetText(L["This part of the installation changes variables in ElvUI"])
			PluginInstallFrame.Desc2:SetText(L["Please click the button below to setup your variables."])
			PluginInstallFrame.Desc3:SetText(L["Importance: |cff07D400High|r"])
			PluginInstallFrame.Option1:Show()
			PluginInstallFrame.Option1:SetScript("OnClick", function() RayUI:SetupVariables("dark") end)
			PluginInstallFrame.Option1:SetText(L["Dark"])
			PluginInstallFrame.Option2:Show()
			PluginInstallFrame.Option2:SetScript("OnClick", function() RayUI:SetupVariables("classColor") end)
			PluginInstallFrame.Option2:SetText(_G.CLASS)
			PluginInstallFrame.Option3:Show()
			PluginInstallFrame.Option3:SetScript("OnClick", function() RayUI:SetupVariables("transparent") end)
			PluginInstallFrame.Option3:SetText(L["Transparent"])
		end,
		[4] = function()
			PluginInstallFrame.SubTitle:SetText(L["Layout"])
			PluginInstallFrame.Desc1:SetText(L["This part of the installation changes the default ElvUI look."])
			PluginInstallFrame.Desc2:SetText(L["Please click the button below to setup your layout."])
			PluginInstallFrame.Desc3:SetText(L["Importance: |cff07D400High|r"])
			PluginInstallFrame.Option1:Show()
			PluginInstallFrame.Option1:SetScript("OnClick", function() RayUI:SetupLayout("dps") end)
			PluginInstallFrame.Option1:SetText(L["Tank/ DPS Layout"])
			PluginInstallFrame.Option2:Show()
			PluginInstallFrame.Option2:SetScript("OnClick", function() RayUI:SetupLayout("healer") end)
			PluginInstallFrame.Option2:SetText(L["Heal Layout"])
		end,
		[5] = function()
			PluginInstallFrame.SubTitle:SetText(L["CVars"])
			PluginInstallFrame.Desc1:SetFormattedText(L["This step changes a few World of Warcraft default options. These options are tailored to the needs of the author of %s and are not necessary for this edit to function."], RayUI.Title)
			PluginInstallFrame.Desc2:SetText(L["Please click the button below to setup your CVars."])
			PluginInstallFrame.Desc3:SetText(L["Importance: |cffFF0000Low|r"])
			PluginInstallFrame.Option1:Show()
			PluginInstallFrame.Option1:SetScript("OnClick", function() RayUI:SetupCVars() end)
			PluginInstallFrame.Option1:SetText(L["CVars"])
		end,
		[6] = function()
			PluginInstallFrame.SubTitle:SetText(L["Chat"])
			PluginInstallFrame.Desc1:SetText(L["This part of the installation process sets up your chat fonts and colors."])
			PluginInstallFrame.Desc2:SetText(L["Please click the button below to setup your chat windows."])
			PluginInstallFrame.Desc3:SetText(L["Importance: |cffD3CF00Medium|r"])
			PluginInstallFrame.Option1:Show()
			PluginInstallFrame.Option1:SetScript("OnClick", function() RayUI:SetupChat() end)
			PluginInstallFrame.Option1:SetText(L["Setup Chat"])
		end,
		[7] = function()
			PluginInstallFrame.SubTitle:SetFormattedText("%s", ADDONS)
			PluginInstallFrame.Desc1:SetText(L["This part of the installation process will apply changes to ElvUI Plugins"])
			PluginInstallFrame.Desc2:SetText(L["Please click the button below to setup the ElvUI AddOns. For other Addon profiles please go in my Options - Skins/AddOns"])
			PluginInstallFrame.Desc3:SetText(L["Importance: |cffD3CF00Medium|r"])
			PluginInstallFrame.Option1:Show()
			PluginInstallFrame.Option1:SetScript("OnClick", function() RayUI:SetupAddOns() end)
			PluginInstallFrame.Option1:SetText(L["Setup Addons"])
		end,
		[8] = function()
			PluginInstallFrame.SubTitle:SetText(L["Installation Complete"])
			PluginInstallFrame.Desc1:SetText(L["You are now finished with the installation process. If you are in need of technical support please visit us at http://www.tukui.org."])
			PluginInstallFrame.Desc2:SetText(L["Please click the button below so you can setup variables and ReloadUI."])
			PluginInstallFrame.Option1:Show()
			PluginInstallFrame.Option1:SetScript("OnClick", function() InstallComplete() end)
			PluginInstallFrame.Option1:SetText(L["Finished"])

			if InstallStepComplete then
				InstallStepComplete.message = RayUI.Title..L["Installed"]
				InstallStepComplete:Show()
			end
		end,
	},

	["StepTitles"] = {
		[1] = START,
		[2] = L["Profiles"],
		[3] = L["Variables"],
		[4] = L["Layout"],
		[5] = L["CVars"],
		[6] = L["Chat"],
		[7] = ADDONS,
		[8] = L["Installation Complete"],
	},
	StepTitlesColorSelected = E.myclass == "PRIEST" and E.PriestColors or RAID_CLASS_COLORS[E.myclass],
	StepTitleWidth = 200,
	StepTitleButtonWidth = 200,
	StepTitleTextJustification = "CENTER",
}
